package com.concatsys.tradein.tradein_plugin.activity;

import android.content.Intent;
import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.MenuItem;
import android.view.View;
import android.view.WindowManager;
import android.widget.FrameLayout;
import android.widget.ImageView;
import android.widget.TextView;

import androidx.appcompat.app.ActionBarDrawerToggle;
import androidx.appcompat.app.AppCompatActivity;
import androidx.core.view.GravityCompat;
import androidx.drawerlayout.widget.DrawerLayout;

import com.concatsys.tradein.tradein_plugin.db.DBOperations;
import com.google.android.material.navigation.NavigationView;
import com.concatsys.tradein.tradein_plugin.R;
import com.concatsys.tradein.tradein_plugin.api.ConstantsApi;
import com.concatsys.tradein.tradein_plugin.logs.LoggerTradeIn;
import com.concatsys.tradein.tradein_plugin.sharedpreference.SharedPreferenceTI;

public class BaseActivity extends AppCompatActivity implements NavigationView.OnNavigationItemSelectedListener {
    private String TAG = getClass().getSimpleName();
    private int mLayoutInflateRes;

    /* Layout ID */
    protected void setLayout(int layoutInflateRes) {
        mLayoutInflateRes = layoutInflateRes;
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_nav_drawer);
//        requestWindowFeature(Window.FEATURE_NO_TITLE);
        getWindow().setFlags(WindowManager.LayoutParams.FLAG_FULLSCREEN, WindowManager.LayoutParams.FLAG_FULLSCREEN);
        FrameLayout frameLayoutNavAddView = findViewById(R.id.fl_nav_add_view);
        LayoutInflater inflaterNav = LayoutInflater.from(this);
        View viewInflate = inflaterNav.inflate(mLayoutInflateRes, null); //here item is the the layout you want to inflate
        frameLayoutNavAddView.addView(viewInflate);
        DBOperations dbOperations = DBOperations.getInstance();
        dbOperations.getMyVehicleSize(BaseActivity.this);
        navigationOperations();
    }

    private DrawerLayout drawerLayout;
    /* Navigation Drawer Operations */
    private void navigationOperations() {
        LoggerTradeIn.e(TAG, "navigationOperations");
        drawerLayout = (DrawerLayout) findViewById(R.id.drawer_layout);
        final ActionBarDrawerToggle actionBarDrawerToggle = new ActionBarDrawerToggle(
                this, drawerLayout, null, R.string.navigation_drawer_open, R.string.navigation_drawer_close);
//        drawer.setDrawerListener(toggle);
        drawerLayout.addDrawerListener(actionBarDrawerToggle);
        actionBarDrawerToggle.syncState();

        final NavigationView navigationView = (NavigationView) findViewById(R.id.navigation_view);
        navigationView.setNavigationItemSelectedListener(this);
        navigationView.setItemIconTintList(null);
        navigationView.getMenu().getItem(0).setChecked(true);
//
        ImageView imageViewNavOptions = (ImageView) findViewById(R.id.iv_nav_options);
        imageViewNavOptions.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                drawerLayout.openDrawer(GravityCompat.END);
            }
        });
        TextView tvAppBarTitle = findViewById(R.id.tv_app_top_bar_title);
        tvAppBarTitle.setText(ConstantsActivity.ACTIVITY_TITLES);

        ImageView imageViewNavBack = (ImageView) findViewById(R.id.iv_nav_back);
        imageViewNavBack.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                finish();
            }
        });
        View viewTopBarLine = findViewById(R.id.view_top_bar_line);

        if (ConstantsActivity.ACTIVITY_TITLES.length() < 1) {
            tvAppBarTitle.setVisibility(View.GONE);
            imageViewNavBack.setVisibility(View.GONE);
            viewTopBarLine.setVisibility(View.GONE);
        } else {
            tvAppBarTitle.setVisibility(View.VISIBLE);
            imageViewNavBack.setVisibility(View.VISIBLE);
            viewTopBarLine.setVisibility(View.VISIBLE);
        }
    }


    public void callAPI(String callApiName){
        ConstantsApi.FLAG_API_NAME = callApiName;
        Intent intent = new Intent(getApplicationContext(), ApiCallsActivity.class);
        startActivity(intent);
    }

    @Override
    public void onBackPressed() {
        LoggerTradeIn.e(TAG, "onBackPressed");
        if (drawerLayout.isDrawerOpen(GravityCompat.END)) {
            drawerLayout.closeDrawer(GravityCompat.END);
        } else {
            super.onBackPressed();
        }
    }

    /* Navigation Clicked*/
    @Override
    public boolean onNavigationItemSelected(MenuItem menuItem) {
        LoggerTradeIn.e(TAG, "onNavigationItemSelected");
        // Handle navigation view item clicks here.
        int idMenuItem = menuItem.getItemId();
        if (idMenuItem == R.id.nav_vehicle) {
            LoggerTradeIn.e(TAG, "nav_vehicle Selected");
            navigationIntent(MyVehicleActivity.class);
        } else if (idMenuItem == R.id.nav_message) {
            LoggerTradeIn.e(TAG, "nav_message Selected");
            navigationIntent(MessageChatActivity.class);
        } else if (idMenuItem == R.id.nav_offers) {
            LoggerTradeIn.e(TAG, "nav_offers Selected");
            navigationIntent(OffersActivity.class);
        } else if (idMenuItem == R.id.nav_profile) {
            LoggerTradeIn.e(TAG, "nav_profile Selected");
//            navigationIntent(ProfileStatusActivity.class);
//            navigationIntent(MyProfileActivity.class);
        } else if (idMenuItem == R.id.nav_contact_us) {
            LoggerTradeIn.e(TAG, "nav_contact_us Selected");
            navigationIntent(ContactUsActivity.class);
        } else if (idMenuItem == R.id.nav_settings) {
            LoggerTradeIn.e(TAG, "nav_contact_us Selected");
            navigationIntent(LogsCaptureSettingsActivityV2.class);
        }
        drawerLayout.closeDrawer(GravityCompat.END);
        return true;
    }
    public SharedPreferenceTI sharedPreferenceTI;
    /* Shared Prefs */
    public void initSharedPrefs(String spKey, String spValue){
        LoggerTradeIn.e(TAG, "initSharedPrefs");
        sharedPreferenceTI = SharedPreferenceTI.getInstance();
        sharedPreferenceTI.putStringValue(this, spKey, spValue);
    }

    /* Common Intent  */
    private void navigationIntent(Class intentScreen) {
        LoggerTradeIn.e(TAG, "navigationIntent");
        Intent intent = new Intent(this, intentScreen);
        if(intentScreen == MyVehicleActivity.class){
            intent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK | Intent.FLAG_ACTIVITY_CLEAR_TASK);
        }
        startActivity(intent);
        if(intentScreen == MyVehicleActivity.class){
            finish();
        }
    }
}
