package com.concatsys.tradein.tradein_plugin.activity;

import android.content.Intent;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.recyclerview.widget.ItemTouchHelper;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import com.concatsys.tradein.tradein_plugin.R;
import com.concatsys.tradein.tradein_plugin.adapter.DBVehiclesAdapter;
import com.concatsys.tradein.tradein_plugin.db.ConstantsDB;
import com.concatsys.tradein.tradein_plugin.db.DBOperations;
import com.concatsys.tradein.tradein_plugin.db.DBVehiclesModel;
import com.concatsys.tradein.tradein_plugin.logs.LoggerTradeIn;

public class MyVehicleActivityV1 extends BaseActivity implements View.OnClickListener {
    private String TAG = getClass().getSimpleName();
    private RecyclerView rvMyVehicleDb;
    private TextView tvMyVehicleAdd;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        ConstantsActivity.ACTIVITY_TITLES = getString(R.string.my_vehicle);
        super.setLayout(R.layout.activity_my_vehicle);
        super.onCreate(savedInstanceState);
        LoggerTradeIn.e(TAG, "onCreate @30");
        initUI();
    }

    /* Initialize UI */
    private void initUI() {
        LoggerTradeIn.e(TAG, "initUI");
        tvMyVehicleAdd = findViewById(R.id.tv_my_vehicle_add);
        tvMyVehicleAdd.setOnClickListener(this);
        initSharedPrefs(ConstantsDB.SHARED_PREFS_SCREEN_KEY, getString(R.string.my_vehicle));
        recyclerViewDisplay();
    }

    @Override
    protected void onResume() {
        super.onResume();
        if(ConstantsActivity.flagUpdateEdit){
            ConstantsActivity.flagUpdateEdit = false;
            initSharedPrefs(ConstantsDB.SHARED_PREFS_SCREEN_KEY, getString(R.string.my_vehicle));
            recyclerViewDisplay();
        }
    }

    /* Initialize Recycler UI */
    private void recyclerViewDisplay() {
        //setting layout manager to our adapter class.
        LoggerTradeIn.e(TAG, "recyclerViewDisplay");
        rvMyVehicleDb = findViewById(R.id.rv_my_vehicle_db);
        rvMyVehicleDb.setLayoutManager(new LinearLayoutManager(this));
        rvMyVehicleDb.setHasFixedSize(true);
        //initializing for recycler view.
        final DBVehiclesAdapter DBVehiclesAdapter = new DBVehiclesAdapter();
        //setting  class for recycler view.
        rvMyVehicleDb.setAdapter(DBVehiclesAdapter);

        ConstantsDB.listVehiclesModel.clear();
        DBOperations dbOperations = DBOperations.getInstance();
        dbOperations.getMyVehicleSize(this);
        DBVehiclesAdapter.submitList(ConstantsDB.listVehiclesModel);

        DBVehiclesAdapter.setOnItemClickListener(new DBVehiclesAdapter.OnItemClickListener() {
            @Override
            public void onItemClick(DBVehiclesModel dbModelUpdate) {
                int id = dbModelUpdate.getVehicle_id();
                displayRoom(dbModelUpdate);
            }
        });

        //below method is use to add swipe to delete method for item of recycler view.
        new ItemTouchHelper(new ItemTouchHelper.SimpleCallback(0, ItemTouchHelper.LEFT | ItemTouchHelper.RIGHT) {
            @Override
            public boolean onMove(@NonNull RecyclerView recyclerView, @NonNull RecyclerView.ViewHolder viewHolder, @NonNull RecyclerView.ViewHolder target) {
                return false;
            }

            @Override
            public void onSwiped(@NonNull RecyclerView.ViewHolder viewHolder, int direction) {
                //on recycler view item swiped then we are deleting the item of our recycler view.
//                deleteRoom(dataBaseAdapter.getValuesInAt(viewHolder.getAdapterPosition()));
            }
        }).attachToRecyclerView(rvMyVehicleDb);
    }

    private void displayRoom(DBVehiclesModel DBVehiclesModelDisplay) {
        LoggerTradeIn.e(TAG, "displayRoom");
        String strDisplayRoom = DBVehiclesModelDisplay.getVehicle_id() + "";
        LoggerTradeIn.e(TAG, "strDisplayRoom " +strDisplayRoom);
//        Toast.makeText(this, "ID - " + strDisplayRoom, Toast.LENGTH_SHORT).show();
    }

    /* On Click  */
    @Override
    public void onClick(View v) {
        LoggerTradeIn.e(TAG, "Button Click");
        if (v.getId() == R.id.tv_my_vehicle_add) {
            LoggerTradeIn.e(TAG, "Add Vehicle Click");
            ConstantsDB.dbVehicleIndex = ConstantsDB.listVehiclesModel.size() + 1;
            ConstantsDB.dbUserIndex = ConstantsDB.listVehiclesModel.size() + 1;
            Intent intent = new Intent(getApplicationContext(), AddVehicleActivity.class);
            startActivity(intent);
        }
    }
}
