package com.concatsys.tradein.tradein_plugin.activity;

import android.content.Intent;
import android.graphics.Color;
import android.os.Bundle;
import android.view.View;
import android.view.WindowManager;
import android.widget.EditText;
import android.widget.TextView;

import com.concatsys.tradein.tradein_plugin.R;
import com.concatsys.tradein.tradein_plugin.api.ApiService;
import com.concatsys.tradein.tradein_plugin.api.ConstantsApi;
import com.concatsys.tradein.tradein_plugin.db.ConstantsDB;
import com.concatsys.tradein.tradein_plugin.db.DBOperations;
import com.concatsys.tradein.tradein_plugin.dialogsandviews.ConstantsDialog;
import com.concatsys.tradein.tradein_plugin.dialogsandviews.DialogCustomize;
import com.concatsys.tradein.tradein_plugin.dialogsandviews.ToastCustomize;
import com.concatsys.tradein.tradein_plugin.interfaces.ActivityCallBack;
import com.concatsys.tradein.tradein_plugin.interfaces.DialogCallBack;
import com.concatsys.tradein.tradein_plugin.logs.LoggerTradeIn;
import com.concatsys.tradein.tradein_plugin.sharedpreference.SharedPreferenceTI;
import com.concatsys.tradein.tradein_plugin.utils.DateAndTimeUtils;
import com.concatsys.tradein.tradein_plugin.utils.EmailValidations;

public class UserProfileActivity extends BaseActivity implements View.OnClickListener, DialogCallBack, ActivityCallBack {
    private String TAG = getClass().getSimpleName();
    public static UserProfileActivity userProfileActivity;
    String strMyLeadKey = "";
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        ConstantsActivity.ACTIVITY_TITLES = getString(R.string.user_profile);
        super.setLayout(R.layout.activity_user_profile);
        super.onCreate(savedInstanceState);
        userProfileActivity = this;
        initUI();
    }

    private EditText etUserProfileFirstName, etUserProfileLastName, etUserProfileEmail, etUserProfilePhone, etUserProfileZip;
    private TextView tvUPCancel, tvUPSave;

    /* Initialize UI */
    private void initUI() {
        LoggerTradeIn.e(TAG, "initUI");
        etUserProfileFirstName = findViewById(R.id.et_user_profile_first_name);
        etUserProfileLastName = findViewById(R.id.et_user_profile_last_name);
        etUserProfileEmail = findViewById(R.id.et_user_profile_email);
        etUserProfilePhone = findViewById(R.id.et_user_profile_phone);
        etUserProfileZip = findViewById(R.id.et_user_profile_zip);
        tvUPCancel = findViewById(R.id.tv_up_cancel);
        tvUPSave = findViewById(R.id.tv_up_save);
        tvUPCancel.setOnClickListener(this);
        tvUPSave.setOnClickListener(this);
        this.getWindow().setSoftInputMode(WindowManager.LayoutParams.SOFT_INPUT_STATE_HIDDEN);
//        setDBValuesToUI();
        initSharedPrefs(ConstantsDB.SHARED_PREFS_SCREEN_KEY, getString(R.string.user_profile));
        setUpdateValuesToUI();
        sharedPreferenceTI = SharedPreferenceTI.getInstance();
        strMyLeadKey = sharedPreferenceTI.getStringValue(this, ConstantsDB.SHARED_PREFS_LEAD_KEY);
        LoggerTradeIn.e(TAG,strMyLeadKey+" @**LKey2");
    }

    /* Db Values Assign to UI */
    private void setDBValuesToUI() {
        LoggerTradeIn.e(TAG, "setDBValuesToUI");
        if (ConstantsActivity.hmUsers.size() == 0) {
            initSharedPrefs(ConstantsDB.SHARED_PREFS_SCREEN_KEY, getString(R.string.user_profile));
            return;
        }
        setDBValue(etUserProfileFirstName, ConstantsActivity.hmUsers.get("user_first_name"));
        setDBValue(etUserProfileLastName, ConstantsActivity.hmUsers.get("user_last_name"));
        setDBValue(etUserProfileEmail, ConstantsActivity.hmUsers.get("user_email"));
        setDBValue(etUserProfilePhone, ConstantsActivity.hmUsers.get("user_phone_number"));
        setDBValue(etUserProfileZip, ConstantsActivity.hmUsers.get("user_zip_code"));
    }

    /*  Values Assign to UI */
    private void setUpdateValuesToUI() {
        if (ConstantsActivity.ACTIVITY_UPDATE_FLAG.equals(ConstantsActivity.ACTIVITY_UPDATE_FLAG_NEW)) {
            return;
        }
        setDBValue(etUserProfileFirstName, ConstantsActivity.STR_UP_FIRST_NAME);
        setDBValue(etUserProfileLastName, ConstantsActivity.STR_UP_LAST_NAME);
        setDBValue(etUserProfileEmail, ConstantsActivity.STR_UP_EMAIL);
        setDBValue(etUserProfilePhone, ConstantsActivity.STR_UP_PHONE);
        setDBValue(etUserProfileZip, ConstantsActivity.STR_UP_ZIP);
    }

    /* Edit Text Value Assign */
    private void setDBValue(EditText editTextDB, String dbValue) {
        LoggerTradeIn.e(TAG, "setDBValue");
        editTextDB.setText(dbValue);
        editTextDB.setTextColor(Color.BLACK);
    }

    /* On Click  */
    @Override
    public void onClick(View v) {
        LoggerTradeIn.e(TAG, "View Clicked");
        if (v.getId() == R.id.tv_up_cancel) {
            LoggerTradeIn.e(TAG, "Cancel Clicked");
            DialogCustomize dialogCustomize = DialogCustomize.getInstance();
            dialogCustomize.displayCancelDialog(this, ConstantsDialog.FLAG_DIALOG_DISPLAY, "", "");
        } else if (v.getId() == R.id.tv_up_save) {
            LoggerTradeIn.e(TAG, "Save Clicked");
            String firstNameUP = etUserProfileFirstName.getText().toString().trim();
            String lastNameUP = etUserProfileLastName.getText().toString().trim();
            String emailUP = etUserProfileEmail.getText().toString().trim();
            String phoneUP = etUserProfilePhone.getText().toString().trim();
            String zipUP = etUserProfileZip.getText().toString().trim();
            if (firstNameUP != null || lastNameUP != null || emailUP != null
                    || phoneUP != null || zipUP != null) {
                if (firstNameUP.length() < 1 || lastNameUP.length() < 1 || emailUP.length() < 1
                        || phoneUP.length() < 1 || zipUP.length() < 1) {

                    ConstantsActivity.ERROR_MESSAGE_VALIDATE = getString(R.string.error_message_validate);
                    DialogCustomize dialogCustomize = DialogCustomize.getInstance();
                    dialogCustomize.displayValidationDialog(this, ConstantsDialog.FLAG_DIALOG_DISPLAY, "", ConstantsActivity.ERROR_MESSAGE_VALIDATE);

                    return;
                }

                if(!EmailValidations.isValidEmailId(emailUP)){
                    ToastCustomize.displayToast(getApplicationContext(), getString(R.string.error_email_validate));
                    return;
                }
//                LEAD_KEY_UP_URL =
                ConstantsApi.FIRST_NAME_UP_URL = firstNameUP;
                ConstantsApi.LAST_NAME_UP_URL = lastNameUP;
                ConstantsApi.EMAIL_UP_URL = emailUP;
                ConstantsApi.PHONE_UP_URL = phoneUP;
                ConstantsApi.ZIP_UP_URL = zipUP;
                ConstantsApi.USER_ID_UP_URL = "1";
                ConstantsApi.CLIENT_ID_UP_URL = "1";

                DBOperations dbOperations = DBOperations.getInstance();
                dbOperations.updateUsers(this, ConstantsDB.dbUserIndex, "", "",
                        "", firstNameUP, lastNameUP, emailUP, phoneUP, zipUP, DateAndTimeUtils.getDateTimeFormat(), DateAndTimeUtils.getDateTimeFormat());
                /*if (ConstantsActivity.flagUpdateEdit) {
                    finish();
                    return;
                }*/
                LoggerTradeIn.e(TAG, strMyLeadKey +" @**LKey3");
                LoggerTradeIn.e(TAG, ConstantsApi.LEAD_KEY +" @**LKey4");
                if (strMyLeadKey.equals(getString(R.string.add_vehicle))) {
                    startUserProfileApi();
                } else {
                    LoggerTradeIn.e(TAG, strMyLeadKey+" @125");
                    nextScreen();
                }
            } else {
                ConstantsActivity.ERROR_MESSAGE_VALIDATE = getString(R.string.error_message_validate);
                DialogCustomize dialogCustomize = DialogCustomize.getInstance();
                dialogCustomize.displayValidationDialog(this, ConstantsDialog.FLAG_DIALOG_DISPLAY, "", ConstantsActivity.ERROR_MESSAGE_VALIDATE);
            }

        }
    }

    /*  Activity Call Api  */
    private void startUserProfileApi() {
        ConstantsApi.FLAG_API_NAME = ConstantsApi.FLAG_API_USER_PROFILE;
        LoggerTradeIn.e(TAG, "API_NAME = " + ConstantsApi.FLAG_API_NAME);
        Intent serviceIntent = new Intent(this, ApiService.class);
        startService(serviceIntent);
    }

    /* Call Back Activity Interface  */
    @Override
    public void callActivity(String strResponse) {
//        LoggerTradeIn.e(TAG, strResponse + " @182");
        LoggerTradeIn.e(TAG, ConstantsApi.LEAD_KEY + " @**LKey1");
        initSharedPrefs(ConstantsDB.SHARED_PREFS_LEAD_KEY, ConstantsApi.LEAD_KEY);
        nextScreen();
    }

    private void nextScreen(){
        Intent in = new Intent(getApplicationContext(), SummaryActivity.class);
        startActivity(in);
//        finish();
    }
    /* Dialog Operations  */
    @Override
    public void sendDialogFlag(int flag) {
        LoggerTradeIn.e(TAG, "sendDialogFlag");
        /*if (flag == ConstantsDialog.FLAG_DIALOG_CANCEL_YES) {
            finish();
        }*/
    }

}
