package com.concatsys.tradein.tradein_plugin.activity;

import android.app.Activity;
import android.content.Intent;
import android.graphics.Color;
import android.os.Bundle;
import android.view.View;
import android.view.WindowManager;
import android.widget.EditText;
import android.widget.LinearLayout;
import android.widget.TextView;

import androidx.activity.result.ActivityResult;
import androidx.activity.result.ActivityResultCallback;
import androidx.activity.result.ActivityResultLauncher;
import androidx.activity.result.contract.ActivityResultContracts;

import com.concatsys.tradein.tradein_plugin.R;
import com.concatsys.tradein.tradein_plugin.api.ApiService;
import com.concatsys.tradein.tradein_plugin.api.ConstantsApi;
import com.concatsys.tradein.tradein_plugin.db.ConstantsDB;
import com.concatsys.tradein.tradein_plugin.db.DBOperations;
import com.concatsys.tradein.tradein_plugin.dialogsandviews.ConstantsDialog;
import com.concatsys.tradein.tradein_plugin.dialogsandviews.DialogCustomize;
import com.concatsys.tradein.tradein_plugin.dialogsandviews.ToastCustomize;
import com.concatsys.tradein.tradein_plugin.interfaces.DialogCallBack;
import com.concatsys.tradein.tradein_plugin.logs.LoggerTradeIn;

import java.util.ArrayList;
import java.util.HashMap;

public class VehicleInfoOneActivity extends BaseActivity implements View.OnClickListener, DialogCallBack {
    private String TAG = getClass().getSimpleName();

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        ConstantsActivity.ACTIVITY_TITLES = getString(R.string.vehicle_info);
        super.setLayout(R.layout.activity_vehicle_info_one);
        super.onCreate(savedInstanceState);

//        callAPI(ConstantsApi.FLAG_API_DROP_DOWN);
        initUI();

    }

    @Override
    protected void onResume() {
        super.onResume();
        LoggerTradeIn.e(TAG, "onResume");
    }

    private TextView textViewHolder, textViewYear, textViewMake, textViewModel, textViewTrim, textViewExteriorColor, textViewVIOneCancel, textViewVIOneSave;
    private EditText etVehicleInfoMileage, etVehicleInfoVin;
    private LinearLayout lytVIOneYear, lytVIOneMake, lytVIOneModel, lytVIOneTrim, lytVIOneExteriorColor;

    /* Initialize UI */
    private void initUI() {
        LoggerTradeIn.e(TAG, "initUI");
        LoggerTradeIn.e(TAG, "dbVehicleIndex = " + ConstantsDB.dbVehicleIndex + "");
        textViewYear = findViewById(R.id.tv_vehicle_info_year);
        textViewMake = findViewById(R.id.tv_vehicle_info_make);
        textViewModel = findViewById(R.id.tv_vehicle_info_model);
        textViewTrim = findViewById(R.id.tv_vehicle_info_trim);
        textViewExteriorColor = findViewById(R.id.tv_vehicle_info_exterior_color);
        etVehicleInfoMileage = findViewById(R.id.et_vehicle_info_mileage);
        etVehicleInfoVin = findViewById(R.id.et_vehicle_info_vin);
        textViewVIOneCancel = findViewById(R.id.tv_vi_one_cancel);
        textViewVIOneSave = findViewById(R.id.tv_vi_one_save);
        textViewVIOneCancel.setOnClickListener(this);
        textViewVIOneSave.setOnClickListener(this);

        lytVIOneYear = findViewById(R.id.lyt_vi_one_year);
        lytVIOneMake = findViewById(R.id.lyt_vi_one_make);
        lytVIOneModel = findViewById(R.id.lyt_vi_one_model);
        lytVIOneTrim = findViewById(R.id.lyt_vi_one_trim);
        lytVIOneExteriorColor = findViewById(R.id.lyt_vi_one_exterior_color);
        lytVIOneYear.setOnClickListener(this);
        lytVIOneMake.setOnClickListener(this);
        lytVIOneModel.setOnClickListener(this);
        lytVIOneTrim.setOnClickListener(this);
        lytVIOneExteriorColor.setOnClickListener(this);
        this.getWindow().setSoftInputMode(WindowManager.LayoutParams.SOFT_INPUT_STATE_HIDDEN);
        initSharedPrefs(ConstantsDB.SHARED_PREFS_SCREEN_KEY, getString(R.string.vehicle_info_one));
        setUpdateValuesToUI();
    }

    /* Db Values Assign to UI */
    private void setDBValuesToUI() {
        LoggerTradeIn.e(TAG, "setDBValuesToUI");
        if (ConstantsActivity.hmDBVehicles.size() == 0) {
            initSharedPrefs(ConstantsDB.SHARED_PREFS_SCREEN_KEY, getString(R.string.vehicle_info_one));
            return;
        }
        setDBValue(textViewYear, ConstantsActivity.hmDBVehicles.get("year"));
        ConstantsApi.MAKE_ID = ConstantsActivity.hmDBVehicles.get("make");
        setDBValue(textViewMake, ConstantsActivity.hmDBVehicles.get("make_name"));
        ConstantsApi.MODEL_ID = ConstantsActivity.hmDBVehicles.get("model");
        setDBValue(textViewModel, ConstantsActivity.hmDBVehicles.get("model_name"));
        setDBValue(textViewTrim, ConstantsActivity.hmDBVehicles.get("trim"));
        setDBValue(etVehicleInfoMileage, ConstantsActivity.hmDBVehicles.get("mileage"));
        setDBValue(etVehicleInfoVin, ConstantsActivity.hmDBVehicles.get("vin"));
        setDBValue(textViewExteriorColor, ConstantsActivity.hmDBVehicles.get("exterior_color"));
    }

    private void setApiValuesToUI() {
        setDBValue(textViewYear, ConstantsApi.alHMMYVEHICLES.get(0).get(ConstantsApi.KEYS_GET_VEHICLES[4]));
        ConstantsApi.MAKE_ID = ConstantsApi.alHMMYVEHICLES.get(0).get(ConstantsApi.KEYS_GET_VEHICLES[26]);
        setDBValue(textViewMake, ConstantsApi.alHMMYVEHICLES.get(0).get(ConstantsApi.KEYS_GET_VEHICLES[5]));
        ConstantsApi.MODEL_ID = ConstantsApi.alHMMYVEHICLES.get(0).get(ConstantsApi.KEYS_GET_VEHICLES[27]);
        setDBValue(textViewModel, ConstantsApi.alHMMYVEHICLES.get(0).get(ConstantsApi.KEYS_GET_VEHICLES[6]));
        setDBValue(textViewTrim, ConstantsApi.alHMMYVEHICLES.get(0).get(ConstantsApi.KEYS_GET_VEHICLES[7]));
        setDBValue(etVehicleInfoMileage, ConstantsApi.alHMMYVEHICLES.get(0).get(ConstantsApi.KEYS_GET_VEHICLES[8]));
        setDBValue(etVehicleInfoVin, ConstantsApi.alHMMYVEHICLES.get(0).get(ConstantsApi.KEYS_GET_VEHICLES[9]));
        setDBValue(textViewExteriorColor, ConstantsApi.alHMMYVEHICLES.get(0).get(ConstantsApi.KEYS_GET_VEHICLES[10]));
    }

    /*  Values Assign to UI */
    private void setUpdateValuesToUI() {
        if (ConstantsActivity.ACTIVITY_UPDATE_FLAG.equals(ConstantsActivity.ACTIVITY_UPDATE_FLAG_NEW)) {
            return;
        }
        setDBValue(textViewYear, ConstantsActivity.STR_VI_YEAR);
        ConstantsApi.MAKE_ID = ConstantsActivity.STR_VI_MAKE;
        setDBValue(textViewMake, ConstantsActivity.STR_VI_MAKE_NAME);
        ConstantsApi.MODEL_ID = ConstantsActivity.STR_VI_MODEL;
        setDBValue(textViewModel, ConstantsActivity.STR_VI_MODEL_NAME);
        setDBValue(textViewTrim, ConstantsActivity.STR_VI_TRIM);
        setDBValue(etVehicleInfoMileage, ConstantsActivity.STR_VI_MILEAGE);
        setDBValue(etVehicleInfoVin, ConstantsActivity.STR_VI_VIN);
        setDBValue(textViewExteriorColor, ConstantsActivity.STR_VI_EXTERIOR_COLOR);
    }

    /* Text View Value Assign */
    private void setDBValue(TextView textViewDB, String dbValue) {
        LoggerTradeIn.e(TAG, "setDBValue TextView");
        textViewDB.setText(dbValue);
        textViewDB.setTextColor(Color.BLACK);
    }

    /* Edit Text Value Assign */
    private void setDBValue(EditText editTextDB, String dbValue) {
        LoggerTradeIn.e(TAG, "setDBValue EditText");
        editTextDB.setText(dbValue);
        editTextDB.setTextColor(Color.BLACK);
    }

    //
    /* Common Intent  */
    private void intentKeyValue(String key, ArrayList<HashMap<String, String>> listValue) {
        LoggerTradeIn.e(TAG, key + " Clicked");
        Intent intent = new Intent(getApplicationContext(), VehicleRadioActivity.class);
        intent.putExtra(key, listValue);
        mStartForResult.launch(intent);
    }

    /* On Result Intent  */
    ActivityResultLauncher<Intent> mStartForResult = registerForActivityResult(new ActivityResultContracts.StartActivityForResult(),
            new ActivityResultCallback<ActivityResult>() {
                @Override
                public void onActivityResult(ActivityResult result) {
                    LoggerTradeIn.e(TAG, "onActivityResult");
                    if (result.getResultCode() == Activity.RESULT_OK) {
                        Intent intent = result.getData();
                        // Handle the Intent
                        ConstantsActivity.SELECT_OPTION_RETURN_VALUE = intent.getStringExtra(ConstantsActivity.SELECT_OPTION_PASS);
                        setValue(ConstantsActivity.SELECT_OPTION_PASS, ConstantsActivity.SELECT_OPTION_RETURN_VALUE);
                        if (ConstantsActivity.SELECT_OPTION_PASS.equalsIgnoreCase(ConstantsApi.KEYS_DROP_DOWN_MAKE[1])) {
                            LoggerTradeIn.e(TAG, "MAKE_ID = " + ConstantsApi.MAKE_ID);
                            ConstantsApi.alHMModel.clear();
//                            callAPI(ConstantsApi.FLAG_API_Model);
                            ConstantsApi.FLAG_API_NAME = ConstantsApi.FLAG_API_Model;
                            Intent serviceIntent = new Intent(VehicleInfoOneActivity.this, ApiService.class);
                            startService(serviceIntent);
                        }

                        if (ConstantsActivity.SELECT_OPTION_PASS.equalsIgnoreCase(ConstantsApi.KEYS_DROP_DOWN_MODEL[1])) {
                            LoggerTradeIn.e(TAG, "MODEL_ID = " + ConstantsApi.MODEL_ID);

                        }
                    }
                }
            });

    /* Text View Value Assign */
    private void setValue(String passValue, String returnValue) {
        LoggerTradeIn.e(TAG, "setValues");
        textViewHolder.setText(returnValue);
        textViewHolder.setTextColor(Color.BLACK);
    }

    /* Dialog Operations  */
    @Override
    public void sendDialogFlag(int flag) {
        LoggerTradeIn.e(TAG, "sendDialogFlag");
        if (flag == ConstantsDialog.FLAG_DIALOG_CANCEL_YES) {
//            activityDiscard();
//            finish();
        }
    }

    /* On Click  */
    @Override
    public void onClick(View v) {
        if (v.getId() == R.id.lyt_vi_one_year) {
            LoggerTradeIn.e(TAG, "Click Year");
            ConstantsActivity.ACTIVITY_TITLES = getString(R.string.select_year);
            textViewHolder = textViewYear;
//            ConstantsActivity.SELECT_OPTION_PASS = ConstantsActivity.SELECT_OPTION_PASS_YEAR;
//            KEYS_DROP_DOWN_RADIO
            ConstantsActivity.SELECT_OPTION_PASS = ConstantsApi.KEYS_DROP_DOWN_YEARS[1];
//            ConstantsActivity.STR_RADIO_VALUE = ConstantsActivity.STR_VI_YEAR;
            ConstantsActivity.STR_RADIO_VALUE = textViewYear.getText().toString();
            intentKeyValue(ConstantsActivity.SELECT_OPTION_PASS, ConstantsApi.alHMYears);
        } else if (v.getId() == R.id.lyt_vi_one_make) {
            LoggerTradeIn.e(TAG, "Click Make");
            ConstantsActivity.ACTIVITY_TITLES = getString(R.string.select_make);
            textViewHolder = textViewMake;
            ConstantsActivity.SELECT_OPTION_PASS = ConstantsApi.KEYS_DROP_DOWN_MAKE[1];
//            ConstantsActivity.STR_RADIO_VALUE = ConstantsActivity.STR_VI_MAKE_NAME;
            ConstantsActivity.STR_RADIO_VALUE = textViewMake.getText().toString();
            intentKeyValue(ConstantsActivity.SELECT_OPTION_PASS, ConstantsApi.alHMMake);
        } else if (v.getId() == R.id.lyt_vi_one_model) {
            LoggerTradeIn.e(TAG, "Click Model");
            /*if (ConstantsApi.alHMModel.size() == 0) {
                ToastCustomize.displayToast(getApplicationContext(), getString(R.string.make_option));
                return;
            }*/
            if (ConstantsApi.MAKE_ID.equals("") || ConstantsApi.MAKE_ID.length() < 1) {
                ToastCustomize.displayToast(getApplicationContext(), getString(R.string.make_option));
                return;
            }
            ConstantsActivity.ACTIVITY_TITLES = getString(R.string.select_model);
            textViewHolder = textViewModel;
            ConstantsActivity.SELECT_OPTION_PASS = ConstantsApi.KEYS_DROP_DOWN_MODEL[1];
//            ConstantsActivity.STR_RADIO_VALUE = ConstantsActivity.STR_VI_MODEL_NAME;
            ConstantsActivity.STR_RADIO_VALUE = textViewModel.getText().toString();
            intentKeyValue(ConstantsActivity.SELECT_OPTION_PASS, ConstantsApi.alHMModel);
        } else if (v.getId() == R.id.lyt_vi_one_trim) {
            LoggerTradeIn.e(TAG, "Click Trim");
            ConstantsActivity.ACTIVITY_TITLES = getString(R.string.select_trim);
            textViewHolder = textViewTrim;
            ConstantsActivity.SELECT_OPTION_PASS = ConstantsApi.KEYS_DROP_DOWN_TRIM[1];
//            ConstantsActivity.STR_RADIO_VALUE = ConstantsActivity.STR_VI_TRIM;
            ConstantsActivity.STR_RADIO_VALUE = textViewTrim.getText().toString();
            intentKeyValue(ConstantsActivity.SELECT_OPTION_PASS, ConstantsApi.alHMTrim);
        } else if (v.getId() == R.id.lyt_vi_one_exterior_color) {
            LoggerTradeIn.e(TAG, "Click Exterior Color");
            ConstantsActivity.ACTIVITY_TITLES = getString(R.string.select_exterior_color);
            textViewHolder = textViewExteriorColor;
            ConstantsActivity.SELECT_OPTION_PASS = ConstantsApi.KEYS_DROP_DOWN_EXTERIOR_COLOR[1];
//            ConstantsActivity.STR_RADIO_VALUE = ConstantsActivity.STR_VI_EXTERIOR_COLOR;
            ConstantsActivity.STR_RADIO_VALUE = textViewExteriorColor.getText().toString();
            intentKeyValue(ConstantsActivity.SELECT_OPTION_PASS, ConstantsApi.alHMExteriorColor);
        } else if (v.getId() == R.id.tv_vi_one_cancel) {
            LoggerTradeIn.e(TAG, "Click Cancel");
            DialogCustomize dialogCustomize = DialogCustomize.getInstance();
            dialogCustomize.displayCancelDialog(this, ConstantsDialog.FLAG_DIALOG_DISPLAY, "", "");
        } else if (v.getId() == R.id.tv_vi_one_save) {
            LoggerTradeIn.e(TAG, "Click Save");
            String yearVI = textViewYear.getText().toString();
            String makeVI = ConstantsApi.MAKE_ID;
            String makeVIName = textViewMake.getText().toString();
            String modelVI = ConstantsApi.MODEL_ID;
            String modelVIName = textViewModel.getText().toString();
            String trimVI = textViewTrim.getText().toString();
            String mileageVI = etVehicleInfoMileage.getText().toString().trim();
            String vinVI = etVehicleInfoVin.getText().toString().trim();
            String exteriorVI = textViewExteriorColor.getText().toString();
            String validationMessage = getString(R.string.enter), invalidStr;
            if (yearVI != null || makeVI != null || modelVI != null
                    || trimVI != null || mileageVI != null || vinVI != null
                    || exteriorVI != null) {
                if (yearVI.length() < 1 || makeVI.length() < 1 || modelVI.length() < 1
                        || trimVI.length() < 1 || mileageVI.length() < 1 || vinVI.length() < 1
                        || exteriorVI.length() < 1
                        || yearVI.contains(getString(R.string.select_space)) || makeVI.contains(getString(R.string.select_space))
                        || modelVI.contains(getString(R.string.select_space)) || trimVI.contains(getString(R.string.select_space))
//                || mileageVI.contains(getString(R.string.select_space)) || vinVI.contains(getString(R.string.select_space))
                        || exteriorVI.contains(getString(R.string.select_space))
                        || mileageVI.equals("0")) {
//            ToastCustomize.displayToast(this,getString(R.string.enter_all_values));
                    if (yearVI.contains(getString(R.string.select_space))) {
                        validationMessage = getString(R.string.year_star);
                    } else if (makeVI.contains(getString(R.string.select_space))) {
                        validationMessage = getString(R.string.make_star);
                    } else if (modelVI.contains(getString(R.string.select_space))) {
                        validationMessage = getString(R.string.model_star);
                    } else if (trimVI.contains(getString(R.string.select_space))) {
                        validationMessage = getString(R.string.trim_star);
                    } else if (mileageVI.length() < 1) {
                        validationMessage = getString(R.string.mileage_star);
                    } else if (vinVI.length() < 1) {
                        validationMessage = getString(R.string.vin_star);
                    } else if (exteriorVI.contains(getString(R.string.select_space))) {
                        validationMessage = getString(R.string.exterior_color_star);
                    }
                    validationMessage = validationMessage.replace(getString(R.string.asterisk_string), "");
                    invalidStr = getString(R.string.invalid);
                    ConstantsActivity.ERROR_MESSAGE_VALIDATE = getString(R.string.error_message_validate);
                    DialogCustomize dialogCustomize = DialogCustomize.getInstance();
                    dialogCustomize.displayValidationDialog(this, ConstantsDialog.FLAG_DIALOG_DISPLAY, "", ConstantsActivity.ERROR_MESSAGE_VALIDATE);
                    return;
                }
                DBOperations dbOperations = DBOperations.getInstance();
                dbOperations.updateVehicleInfo1(this, ConstantsDB.dbVehicleIndex, ConstantsDB.dbUserIndex, "", false, 0.0,
                        yearVI, makeVI, makeVIName, modelVI, modelVIName, trimVI, mileageVI, vinVI, exteriorVI);

                int vehicleInfoPercentage = (int) Math.round(ConstantsDB.dbVehiclePercentage);
                if(vehicleInfoPercentage < 21){
                    ConstantsDB.dbVehiclePercentage = 20;
                    dbOperations.updateVehiclePercentage(this, ConstantsDB.dbVehicleIndex, ConstantsDB.dbVehiclePercentage);
                }
                /*if (ConstantsActivity.flagUpdateEdit) {
                    finish();
                    return;
                }*/
                Intent in = new Intent(getApplicationContext(), VehicleInfoTwoActivity.class);
                startActivity(in);
//                finish();
            } else {
                ConstantsActivity.ERROR_MESSAGE_VALIDATE = getString(R.string.error_message_validate);
                DialogCustomize dialogCustomize = DialogCustomize.getInstance();
                dialogCustomize.displayValidationDialog(this, ConstantsDialog.FLAG_DIALOG_DISPLAY, "", ConstantsActivity.ERROR_MESSAGE_VALIDATE);
            }
        }
    }
}