package com.concatsys.tradein.tradein_plugin.activity;

import android.app.Activity;
import android.content.Intent;
import android.graphics.Color;
import android.os.Bundle;
import android.view.View;
import android.view.WindowManager;
import android.widget.LinearLayout;
import android.widget.TextView;

import androidx.activity.result.ActivityResult;
import androidx.activity.result.ActivityResultCallback;
import androidx.activity.result.ActivityResultLauncher;
import androidx.activity.result.contract.ActivityResultContracts;

import com.concatsys.tradein.tradein_plugin.R;
import com.concatsys.tradein.tradein_plugin.api.ConstantsApi;
import com.concatsys.tradein.tradein_plugin.db.ConstantsDB;
import com.concatsys.tradein.tradein_plugin.db.DBOperations;
import com.concatsys.tradein.tradein_plugin.dialogsandviews.ConstantsDialog;
import com.concatsys.tradein.tradein_plugin.dialogsandviews.DialogCustomize;
import com.concatsys.tradein.tradein_plugin.interfaces.DialogCallBack;
import com.concatsys.tradein.tradein_plugin.logs.LoggerTradeIn;

import java.util.ArrayList;
import java.util.HashMap;

public class VehicleInfoTwoActivity extends BaseActivity implements View.OnClickListener, DialogCallBack {
    private String TAG = getClass().getSimpleName();

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        ConstantsActivity.ACTIVITY_TITLES = getString(R.string.vehicle_info);
        super.setLayout(R.layout.activity_vehicle_info_two);
        super.onCreate(savedInstanceState);
        initUI();
    }

    private TextView textViewHolder, textViewInteriorColor, textViewTransmission, textViewDriveTrain, textViewBodyStyle, textViewEngine, textViewSeatType, textViewVITwoCancel, textViewVITwoSave;
    private LinearLayout lytVITwoInteriorColor, lytVITwoTransmission, lytVITwoDriveTrain, lytVITwoBodyStyle, lytVITwoEngine, lytVITwoSeatType;

    /* Initialize UI */
    private void initUI() {
        LoggerTradeIn.e(TAG, "initUI");
        textViewInteriorColor = findViewById(R.id.tv_vehicle_info_interior_color);
        textViewTransmission = findViewById(R.id.tv_vehicle_info_transmission);
        textViewDriveTrain = findViewById(R.id.tv_vehicle_info_drive_train);
        textViewBodyStyle = findViewById(R.id.tv_vehicle_info_body_style);
        textViewEngine = findViewById(R.id.tv_vehicle_info_engine);
        textViewSeatType = findViewById(R.id.tv_vehicle_info_seat_type);
        textViewVITwoCancel = findViewById(R.id.tv_vi_two_cancel);
        textViewVITwoSave = findViewById(R.id.tv_vi_two_save);
        lytVITwoInteriorColor = findViewById(R.id.lyt_vi_two_interior_color);
        lytVITwoTransmission = findViewById(R.id.lyt_vi_two_transmission);
        lytVITwoDriveTrain = findViewById(R.id.lyt_vi_two_drive_train);
        lytVITwoBodyStyle = findViewById(R.id.lyt_vi_two_body_style);
        lytVITwoEngine = findViewById(R.id.lyt_vi_two_engine);
        lytVITwoSeatType = findViewById(R.id.lyt_vi_two_seat_type);
        textViewVITwoCancel.setOnClickListener(this);
        textViewVITwoSave.setOnClickListener(this);
        lytVITwoInteriorColor.setOnClickListener(this);
        lytVITwoTransmission.setOnClickListener(this);
        lytVITwoDriveTrain.setOnClickListener(this);
        lytVITwoBodyStyle.setOnClickListener(this);
        lytVITwoEngine.setOnClickListener(this);
        lytVITwoSeatType.setOnClickListener(this);
        this.getWindow().setSoftInputMode(WindowManager.LayoutParams.SOFT_INPUT_STATE_HIDDEN);
//        setDBValuesToUI();
        initSharedPrefs(ConstantsDB.SHARED_PREFS_SCREEN_KEY, getString(R.string.vehicle_info_two));
        setUpdateValuesToUI();
    }

    /* Db Values Assign to UI */
    private void setDBValuesToUI() {
        LoggerTradeIn.e(TAG, "setDBValuesToUI");
        if (ConstantsActivity.hmDBVehicles.size() == 0) {
            initSharedPrefs(ConstantsDB.SHARED_PREFS_SCREEN_KEY, getString(R.string.vehicle_info_two));
            return;
        }

        setDBValue(textViewInteriorColor, ConstantsActivity.hmDBVehicles.get("interior_color"));
        setDBValue(textViewTransmission, ConstantsActivity.hmDBVehicles.get("transmission"));
        setDBValue(textViewDriveTrain, ConstantsActivity.hmDBVehicles.get("drive_train"));
        setDBValue(textViewBodyStyle, ConstantsActivity.hmDBVehicles.get("body_style"));
        setDBValue(textViewEngine, ConstantsActivity.hmDBVehicles.get("engine"));
        setDBValue(textViewSeatType, ConstantsActivity.hmDBVehicles.get("seat_type"));

    }

    /*  Values Assign to UI */
    private void setUpdateValuesToUI() {
        if (ConstantsActivity.ACTIVITY_UPDATE_FLAG.equals(ConstantsActivity.ACTIVITY_UPDATE_FLAG_NEW)) {
            return;
        }
        setDBValue(textViewInteriorColor, ConstantsActivity.STR_VI_INTERIOR_COLOR);
        setDBValue(textViewTransmission, ConstantsActivity.STR_VI_TRANSMISSION);
        setDBValue(textViewDriveTrain, ConstantsActivity.STR_VI_DRIVETRAIN);
        setDBValue(textViewBodyStyle, ConstantsActivity.STR_VI_BODY_STYLE);
        setDBValue(textViewEngine, ConstantsActivity.STR_VI_ENGINE);
        setDBValue(textViewSeatType, ConstantsActivity.STR_VI_SEAT_TYPE);
    }
    /* Text View Value Assign */
    private void setDBValue(TextView textViewDB, String dbValue) {
        LoggerTradeIn.e(TAG, "setDBValue");
        textViewDB.setText(dbValue);
        textViewDB.setTextColor(Color.BLACK);
    }
    //
    /* Common Intent  */
   /* private void intentKeyValue(String key, ArrayList<String> listValue) {
        LoggerTradeIn.e(TAG,key+" Clicked");
        Intent intent = new Intent(getApplicationContext(), VehicleRadioActivity.class);
        intent.putStringArrayListExtra(key, listValue);
        mStartForResult.launch(intent);
    }*/

    /* Common Intent  */
    private void intentKeyValue(String key, ArrayList<HashMap<String, String>> listValue) {
        LoggerTradeIn.e(TAG, key + " Clicked");
        Intent intent = new Intent(getApplicationContext(), VehicleRadioActivity.class);
        intent.putExtra(key, listValue);
        mStartForResult.launch(intent);
    }

    /* On Result Intent  */
    ActivityResultLauncher<Intent> mStartForResult = registerForActivityResult(new ActivityResultContracts.StartActivityForResult(),
            new ActivityResultCallback<ActivityResult>() {
                @Override
                public void onActivityResult(ActivityResult result) {
                    LoggerTradeIn.e(TAG, "onActivityResult");
                    if (result.getResultCode() == Activity.RESULT_OK) {
                        Intent intent = result.getData();
                        // Handle the Intent
                        ConstantsActivity.SELECT_OPTION_RETURN_VALUE = intent.getStringExtra(ConstantsActivity.SELECT_OPTION_PASS);
                        setValue(ConstantsActivity.SELECT_OPTION_PASS, ConstantsActivity.SELECT_OPTION_RETURN_VALUE);
                    }
                }
            });

    /* Text View Value Assign */
    private void setValue(String passValue, String returnValue) {
        LoggerTradeIn.e(TAG, "setValue");
        textViewHolder.setText(returnValue);
        textViewHolder.setTextColor(Color.BLACK);
    }

    /* Dialog Operations  */
    @Override
    public void sendDialogFlag(int flag) {
        LoggerTradeIn.e(TAG, "sendDialogFlag");
        if (flag == ConstantsDialog.FLAG_DIALOG_CANCEL_YES) {
//            activityDiscard();
//            finish();
        }
    }

    /* On Click  */
    @Override
    public void onClick(View v) {
        if (v.getId() == R.id.lyt_vi_two_interior_color) {
            LoggerTradeIn.e(TAG, "Click Interior Color");
            ConstantsActivity.ACTIVITY_TITLES = getString(R.string.select_interior_color);
            textViewHolder = textViewInteriorColor;
//            ConstantsActivity.SELECT_OPTION_PASS = ConstantsActivity.SELECT_OPTION_PASS_INTERIOR_COLOR;
            ConstantsActivity.SELECT_OPTION_PASS = ConstantsApi.KEYS_DROP_DOWN_INTERIOR_COLOR[1];
//            ConstantsActivity.STR_RADIO_VALUE = ConstantsActivity.STR_VI_INTERIOR_COLOR;
            ConstantsActivity.STR_RADIO_VALUE = textViewInteriorColor.getText().toString();
            intentKeyValue(ConstantsActivity.SELECT_OPTION_PASS, ConstantsApi.alHMInteriorColor);
        } else if (v.getId() == R.id.lyt_vi_two_transmission) {
            LoggerTradeIn.e(TAG, "Click Transmission");
            ConstantsActivity.ACTIVITY_TITLES = getString(R.string.select_transmission);
            textViewHolder = textViewTransmission;
            ConstantsActivity.SELECT_OPTION_PASS = ConstantsApi.KEYS_DROP_DOWN_TRANSMISSION[1];
//            ConstantsActivity.STR_RADIO_VALUE = ConstantsActivity.STR_VI_TRANSMISSION;
            ConstantsActivity.STR_RADIO_VALUE = textViewTransmission.getText().toString();
            intentKeyValue(ConstantsActivity.SELECT_OPTION_PASS, ConstantsApi.alHMTransmissions);
        } else if (v.getId() == R.id.lyt_vi_two_drive_train) {
            LoggerTradeIn.e(TAG, "Click Drive Train");
            ConstantsActivity.ACTIVITY_TITLES = getString(R.string.select_drivetrain);
            textViewHolder = textViewDriveTrain;
            ConstantsActivity.SELECT_OPTION_PASS = ConstantsApi.KEYS_DROP_DOWN_DRIVE_TRAIN[1];
//            ConstantsActivity.STR_RADIO_VALUE = ConstantsActivity.STR_VI_DRIVETRAIN;
            ConstantsActivity.STR_RADIO_VALUE = textViewDriveTrain.getText().toString();
            intentKeyValue(ConstantsActivity.SELECT_OPTION_PASS, ConstantsApi.alHMDriveTrains);
        } else if (v.getId() == R.id.lyt_vi_two_body_style) {
            LoggerTradeIn.e(TAG, "Click Body Style");
            ConstantsActivity.ACTIVITY_TITLES = getString(R.string.select_body_style);
            textViewHolder = textViewBodyStyle;
            ConstantsActivity.SELECT_OPTION_PASS = ConstantsApi.KEYS_DROP_DOWN_BODY_STYLE[1];
//            ConstantsActivity.STR_RADIO_VALUE = ConstantsActivity.STR_VI_BODY_STYLE;
            ConstantsActivity.STR_RADIO_VALUE = textViewBodyStyle.getText().toString();
            intentKeyValue(ConstantsActivity.SELECT_OPTION_PASS, ConstantsApi.alHMBodyStyles);
        } else if (v.getId() == R.id.lyt_vi_two_engine) {
            LoggerTradeIn.e(TAG, "Click Engine");
            ConstantsActivity.ACTIVITY_TITLES = getString(R.string.select_engine);
            textViewHolder = textViewEngine;
            ConstantsActivity.SELECT_OPTION_PASS = ConstantsApi.KEYS_DROP_DOWN_ENGINE[1];
//            ConstantsActivity.STR_RADIO_VALUE = ConstantsActivity.STR_VI_ENGINE;
            ConstantsActivity.STR_RADIO_VALUE = textViewEngine.getText().toString();
            intentKeyValue(ConstantsActivity.SELECT_OPTION_PASS, ConstantsApi.alHMEngines);
        } else if (v.getId() == R.id.lyt_vi_two_seat_type) {
            LoggerTradeIn.e(TAG, "Click Seat Type");
            ConstantsActivity.ACTIVITY_TITLES = getString(R.string.select_seat_type);
            textViewHolder = textViewSeatType;
            ConstantsActivity.SELECT_OPTION_PASS = ConstantsApi.KEYS_DROP_DOWN_SEAT_TYPE[1];
//            ConstantsActivity.STR_RADIO_VALUE = ConstantsActivity.STR_VI_SEAT_TYPE;
            ConstantsActivity.STR_RADIO_VALUE = textViewSeatType.getText().toString();
            intentKeyValue(ConstantsActivity.SELECT_OPTION_PASS, ConstantsApi.alHMSeatTypes);
        } else if (v.getId() == R.id.tv_vi_two_cancel) {
            LoggerTradeIn.e(TAG, "Click Cancel");
            DialogCustomize dialogCustomize = DialogCustomize.getInstance();
            dialogCustomize.displayCancelDialog(this, ConstantsDialog.FLAG_DIALOG_DISPLAY, "", "");
        } else if (v.getId() == R.id.tv_vi_two_save) {
            LoggerTradeIn.e(TAG, "Click Save");
            String interiorColorVI = textViewInteriorColor.getText().toString();
            String transmissionVI = textViewTransmission.getText().toString();
            String driveTrainVI = textViewDriveTrain.getText().toString();
            String bodyStyleVI = textViewBodyStyle.getText().toString();
            String engineVI = textViewEngine.getText().toString();
            String seatTypeVI = textViewSeatType.getText().toString();
            LoggerTradeIn.e(TAG, interiorColorVI);
            String validationMessage = getString(R.string.enter), invalidStr;

            if (interiorColorVI.length() < 1 || transmissionVI.length() < 1 || driveTrainVI.length() < 1
                    || bodyStyleVI.length() < 1 || engineVI.length() < 1 || seatTypeVI.length() < 1
                    || interiorColorVI.contains(getString(R.string.select_space)) || transmissionVI.contains(getString(R.string.select_space))
                    || driveTrainVI.contains(getString(R.string.select_space)) || bodyStyleVI.contains(getString(R.string.select_space))
                    || engineVI.contains(getString(R.string.select_space)) || seatTypeVI.contains(getString(R.string.select_space))) {

                if (interiorColorVI.contains(getString(R.string.select_space))) {
                    validationMessage = getString(R.string.interior_color);
                    interiorColorVI = "";
                }
                if (transmissionVI.contains(getString(R.string.select_space))) {
                    validationMessage = getString(R.string.transmission);
                    transmissionVI = "";
                }
                if (driveTrainVI.contains(getString(R.string.select_space))) {
                    validationMessage = getString(R.string.drivetrain);
                    driveTrainVI = "";
                }
                if (bodyStyleVI.contains(getString(R.string.select_space))) {
                    validationMessage = getString(R.string.body_style);
                    bodyStyleVI = "";
                }
                if (engineVI.contains(getString(R.string.select_space))) {
                    validationMessage = getString(R.string.engine);
                    engineVI = "";
                }
                if (seatTypeVI.contains(getString(R.string.select_space))) {
                    validationMessage = getString(R.string.seat_type);
                    seatTypeVI = "";
                }

            }
            LoggerTradeIn.e(TAG,transmissionVI+" @231");

            DBOperations dbOperations = DBOperations.getInstance();
            dbOperations.updateVehicleInfo2(this, ConstantsDB.dbVehicleIndex, ConstantsDB.dbUserIndex, "", false, 0.0,
                    interiorColorVI, transmissionVI, driveTrainVI, bodyStyleVI, engineVI, seatTypeVI);

            int vehicleInfoPercentage = (int) Math.round(ConstantsDB.dbVehiclePercentage);
            if(vehicleInfoPercentage < 41){
                ConstantsDB.dbVehiclePercentage = 40;
                dbOperations.updateVehiclePercentage(this, ConstantsDB.dbVehicleIndex, ConstantsDB.dbVehiclePercentage);
            }

            /*if (ConstantsActivity.flagUpdateEdit) {
                finish();
                return;
            }*/
            Intent in = new Intent(getApplicationContext(), VehicleOptionsActivity.class);
            startActivity(in);
//            finish();
        }
    }
}
