package com.concatsys.tradein.tradein_plugin.activity;

import android.app.Activity;
import android.content.Intent;
import android.graphics.Color;
import android.os.Bundle;
import android.view.View;
import android.view.WindowManager;
import android.widget.EditText;
import android.widget.LinearLayout;
import android.widget.TextView;

import androidx.activity.result.ActivityResult;
import androidx.activity.result.ActivityResultCallback;
import androidx.activity.result.ActivityResultLauncher;
import androidx.activity.result.contract.ActivityResultContracts;

import com.concatsys.tradein.tradein_plugin.R;
import com.concatsys.tradein.tradein_plugin.api.ConstantsApi;
import com.concatsys.tradein.tradein_plugin.db.ConstantsDB;
import com.concatsys.tradein.tradein_plugin.db.DBOperations;
import com.concatsys.tradein.tradein_plugin.dialogsandviews.ConstantsDialog;
import com.concatsys.tradein.tradein_plugin.dialogsandviews.DialogCustomize;
import com.concatsys.tradein.tradein_plugin.interfaces.DialogCallBack;
import com.concatsys.tradein.tradein_plugin.logs.LoggerTradeIn;

import java.util.ArrayList;
import java.util.HashMap;

public class VehicleOptionsActivity extends BaseActivity implements View.OnClickListener, DialogCallBack {
    private String TAG = getClass().getSimpleName();

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        ConstantsActivity.ACTIVITY_TITLES = getString(R.string.vehicle_option);
        super.setLayout(R.layout.activity_vehicle_options);
        super.onCreate(savedInstanceState);
        initUI();
    }

    private TextView textViewHolder, textViewOptionsCheckBox, textViewVOCancel, textViewVOSave;
    private EditText etVehicleOptionsPackage;
    private LinearLayout lytVOOptions;

    /* Initialize UI */
    private void initUI() {
        LoggerTradeIn.e(TAG, "initUI");
        textViewOptionsCheckBox = findViewById(R.id.tv_vehicle_options_select);
        etVehicleOptionsPackage = findViewById(R.id.et_vehicle_options_package);
        lytVOOptions = findViewById(R.id.lyt_vo_options);
        textViewVOCancel = findViewById(R.id.tv_vo_cancel);
        textViewVOSave = findViewById(R.id.tv_vo_save);
        lytVOOptions.setOnClickListener(this);
        textViewVOCancel.setOnClickListener(this);
        textViewVOSave.setOnClickListener(this);
        this.getWindow().setSoftInputMode(WindowManager.LayoutParams.SOFT_INPUT_STATE_HIDDEN);
//        setDBValuesToUI();
        initSharedPrefs(ConstantsDB.SHARED_PREFS_SCREEN_KEY, getString(R.string.vehicle_option));
        setUpdateValuesToUI();
    }

    /* Db Values Assign to UI */
    private void setDBValuesToUI() {
        LoggerTradeIn.e(TAG, "setDBValuesToUI");
        if (ConstantsActivity.hmDBVehicles.size() == 0) {
            initSharedPrefs(ConstantsDB.SHARED_PREFS_SCREEN_KEY, getString(R.string.vehicle_option));
            return;
        }
        setDBValue(textViewOptionsCheckBox, ConstantsActivity.hmDBVehicles.get("options"));
        setDBValue(etVehicleOptionsPackage, ConstantsActivity.hmDBVehicles.get("packages"));
    }

    /*  Values Assign to UI */
    private void setUpdateValuesToUI() {
        if (ConstantsActivity.ACTIVITY_UPDATE_FLAG.equals(ConstantsActivity.ACTIVITY_UPDATE_FLAG_NEW)) {
            return;
        }
        strOptions = ConstantsActivity.STR_VO_VEHICLE_OPTIONS_NAMES;
        strOptionsIDS = ConstantsActivity.STR_VO_VEHICLE_OPTIONS_IDS;
        setDBValue(textViewOptionsCheckBox, ConstantsActivity.STR_VO_VEHICLE_OPTIONS_NAMES);
        setDBValue(etVehicleOptionsPackage, ConstantsActivity.STR_VO_PACKAGES);
    }

    /* Text View Value Assign */
    private void setDBValue(TextView textViewDB, String dbValue) {
        LoggerTradeIn.e(TAG, "setDBValue");
        textViewDB.setText(dbValue);
        textViewDB.setTextColor(Color.BLACK);
    }

    /* Edit Text Value Assign */
    private void setDBValue(EditText editTextDB, String dbValue) {
        LoggerTradeIn.e(TAG, "setDBValue");
        editTextDB.setText(dbValue);
        editTextDB.setTextColor(Color.BLACK);
    }

    /* Common Intent  */
    /*private void intentKeyValue(String key, ArrayList<String> listValue) {
        LoggerTradeIn.e(TAG,key +" Clicked");
        Intent intent = new Intent(getApplicationContext(), VehicleCheckBoxActivity.class);
        intent.putStringArrayListExtra(key, listValue);
//        startActivityForResult(intent,1);
        mStartForResult.launch(intent);
    }*/

    /* Common Intent  */
    private void intentKeyValue(String key, ArrayList<HashMap<String, String>> listValue) {
        LoggerTradeIn.e(TAG, key + " Clicked");
        Intent intent = new Intent(getApplicationContext(), VehicleCheckBoxActivity.class);
        intent.putExtra(key, listValue);
        mStartForResult.launch(intent);
    }

    /* On Result Intent  */
    ActivityResultLauncher<Intent> mStartForResult = registerForActivityResult(new ActivityResultContracts.StartActivityForResult(),
            new ActivityResultCallback<ActivityResult>() {
                @Override
                public void onActivityResult(ActivityResult result) {
                    LoggerTradeIn.e(TAG, "onActivityResult");
                    if (result.getResultCode() == Activity.RESULT_OK) {
                        Intent intent = result.getData();
                        // Handle the Intent
                        ConstantsActivity.AL_CHECK_BOX_OPTIONS = intent.getStringArrayListExtra(ConstantsActivity.SELECT_OPTION_PASS);
                        ConstantsActivity.AL_CHECK_BOX_OPTIONS_IDS = intent.getStringArrayListExtra(ConstantsActivity.SELECT_OPTION_PASS_IDS);
//                        ConstantsActivity.SELECT_OPTION_RETURN_VALUE = intent.getStringExtra(ConstantsActivity.SELECT_OPTION_PASS);
//                        LoggerTradeIn.e(TAG,ConstantsActivity.SELECT_OPTION_RETURN_VALUE+"");
                        ConstantsActivity.SELECT_OPTION_RETURN_VALUE = "";
                        ConstantsActivity.SELECT_OPTION_RETURN_VALUE_IDS = "";
                        for (String strCheckBoxValues : ConstantsActivity.AL_CHECK_BOX_OPTIONS) {
                            ConstantsActivity.SELECT_OPTION_RETURN_VALUE += strCheckBoxValues + ", ";
                        }
                        for (String strCheckBoxValuesIDS : ConstantsActivity.AL_CHECK_BOX_OPTIONS_IDS) {
                            ConstantsActivity.SELECT_OPTION_RETURN_VALUE_IDS += strCheckBoxValuesIDS + ", ";
                        }

//                        LoggerTradeIn.e(TAG,ConstantsActivity.SELECT_OPTION_RETURN_VALUE+"");
                        ConstantsActivity.SELECT_OPTION_RETURN_VALUE = ConstantsActivity.SELECT_OPTION_RETURN_VALUE.replaceAll(", $", "");
                        ConstantsActivity.SELECT_OPTION_RETURN_VALUE_IDS = ConstantsActivity.SELECT_OPTION_RETURN_VALUE_IDS.replaceAll(", $", "");
                        setValue(ConstantsActivity.SELECT_OPTION_PASS, ConstantsActivity.SELECT_OPTION_RETURN_VALUE);
                        strOptionsIDS = ConstantsActivity.SELECT_OPTION_RETURN_VALUE_IDS;
                    }
                }
            });

    /* Text View Value Assign */
    private void setValue(String passValue, String returnValue) {
//        LoggerTradeIn.e(TAG,"returnValue = "+ returnValue);
        strOptions = returnValue;
        textViewHolder.setText(returnValue);
        textViewHolder.setTextColor(Color.BLACK);
    }

    String strOptions, strOptionsIDS;

    /* DB Insert  */
    private void insertRoom() {
        LoggerTradeIn.e(TAG, "insert Db");
        String validationMessage = getString(R.string.enter), invalidStr;
        String strPackage = etVehicleOptionsPackage.getText().toString().trim();
        if (strPackage.length() < 1 || ConstantsActivity.AL_CHECK_BOX_OPTIONS.size() < 1
                || ConstantsActivity.SELECT_OPTION_RETURN_VALUE.length() < 1) {
            if (strPackage.length() < 1) {
                validationMessage = getString(R.string.package_string);
            } else if (ConstantsActivity.SELECT_OPTION_RETURN_VALUE.length() < 1) {
                validationMessage = getString(R.string.option_str);
            }
            if (strPackage != null) {
                strPackage = "";
            }
            validationMessage = validationMessage.replace("*", "");
            invalidStr = getString(R.string.invalid);
//            DBVehicleOptionsModelV1 dbVehicleInfoOneModel = new DBVehicleOptionsModelV1();
//            dbVehicleInfoOneModel.setAllTableColumns(strPackage, ConstantsActivity.AL_CHECK_BOX_OPTIONS, ConstantsActivity.SELECT_OPTION_RETURN_VALUE);

//            ConstantsActivity.ERROR_MESSAGE_VALIDATE = getString(R.string.error_message_validate);
//            DialogCustomize dialogCustomize = DialogCustomize.getInstance();
//            dialogCustomize.displayValidationDialog(this, ConstantsDialog.FLAG_DIALOG_DISPLAY, "", ConstantsActivity.ERROR_MESSAGE_VALIDATE);
//                return;
        }
        if (null == strOptions) {
            strOptions = "";
        }
        if (null == strOptionsIDS) {
            strOptionsIDS = "";
        }
        strOptions = strOptions + "--" + strOptionsIDS;
        LoggerTradeIn.e(TAG, strOptions + " @166");
        DBOperations dbOperations = DBOperations.getInstance();
        dbOperations.updateVehicleOptions(this, ConstantsDB.dbVehicleIndex, ConstantsDB.dbUserIndex, "", false, 0.0,
                "", strOptions, strPackage);

        int vehicleInfoPercentage = (int) Math.round(ConstantsDB.dbVehiclePercentage);
        if (vehicleInfoPercentage < 61) {
            ConstantsDB.dbVehiclePercentage = 60;
            dbOperations.updateVehiclePercentage(this, ConstantsDB.dbVehicleIndex, ConstantsDB.dbVehiclePercentage);
        }

        /*if(ConstantsActivity.flagUpdateEdit){
            finish();
            return;
        }*/
        Intent in = new Intent(getApplicationContext(), VehicleConditionActivity.class);
        startActivity(in);
//        finish();
    }

    /* Dialog Operations  */
    @Override
    public void sendDialogFlag(int flag) {
        LoggerTradeIn.e(TAG, "sendDialogFlag");
        if (flag == ConstantsDialog.FLAG_DIALOG_CANCEL_YES) {
//            finish();
        }
    }

    /* On Click  */
    @Override
    public void onClick(View v) {
        LoggerTradeIn.e(TAG, "onClick");
        if (v.getId() == R.id.lyt_vo_options) {
            LoggerTradeIn.e(TAG, "Click Options");
            ConstantsActivity.ACTIVITY_TITLES = getString(R.string.select_vehicle_option);
            textViewHolder = textViewOptionsCheckBox;
//            ConstantsActivity.SELECT_OPTION_PASS = ConstantsActivity.SELECT_OPTION_PASS_VEHICLE_OPTION;
            ConstantsActivity.SELECT_OPTION_PASS = ConstantsApi.KEYS_DROP_DOWN_VEHICLE_OPTION[1];
//            intentKeyValue(ConstantsActivity.SELECT_OPTION_PASS, ConstantsActivity.AL_CHECK_VEHICLE_OPTIONS);
            intentKeyValue(ConstantsActivity.SELECT_OPTION_PASS, ConstantsApi.alHMVehicleOptions);

        } else if (v.getId() == R.id.tv_vo_cancel) {
            LoggerTradeIn.e(TAG, "Click Cancel");
            DialogCustomize dialogCustomize = DialogCustomize.getInstance();
            dialogCustomize.displayCancelDialog(this, ConstantsDialog.FLAG_DIALOG_DISPLAY, "", "");
        } else if (v.getId() == R.id.tv_vo_save) {
            LoggerTradeIn.e(TAG, "Click Save");
            insertRoom();
        }
    }
}
