package com.concatsys.tradein.tradein_plugin.adapter;

import android.content.Context;
import android.content.Intent;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.recyclerview.widget.RecyclerView;

import com.concatsys.tradein.tradein_plugin.R;
import com.concatsys.tradein.tradein_plugin.api.ApiService;
import com.concatsys.tradein.tradein_plugin.api.ConstantsApi;
import com.concatsys.tradein.tradein_plugin.logs.LoggerTradeIn;

import java.util.ArrayList;
import java.util.HashMap;

public class ApiCallsAdapter extends RecyclerView.Adapter<ApiCallsAdapter.AdapterHolder> {
    // List to store all the contact details
    private String TAG = getClass().getSimpleName();
    private ArrayList<HashMap<String, String>> alHashData;
    private Context mContext;
    private int layoutId ;
    // Constructor for the Class
    public ApiCallsAdapter(ArrayList<HashMap<String, String>> alHashData, Context context, int layoutId) {
        this.alHashData = alHashData;
        this.mContext = context;
        this.layoutId = layoutId;
    }
    // This method creates views for the RecyclerView by inflating the layout
    // Into the viewHolders which helps to display the items in the RecyclerView
    @Override
    public AdapterHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
        LayoutInflater layoutInflater = LayoutInflater.from(parent.getContext());
        // Inflate the layout view you have created for the list rows here
        View view = layoutInflater.inflate(layoutId, parent, false);
        return new AdapterHolder(view);
    }
    @Override
    public int getItemCount() {
        return alHashData == null? 0: alHashData.size();
    }
    // This method is called when binding the data to the views being created in RecyclerView
    @Override
    public void onBindViewHolder(@NonNull AdapterHolder holder, final int position) {
//        final Contact contact = contactsList.get(position);
        // Set the data to the views here
        holder.setOfferDollar(alHashData.get(position).get(ConstantsApi.KEYS_OFFERS[1]));
        holder.tvOffersReject.setId(position);
        holder.tvOffersAccept.setId(position);
        holder.tvOffersReject.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                LoggerTradeIn.e(TAG,v.getId()+"");
                callService();
            }
        });
        holder.tvOffersAccept.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                LoggerTradeIn.e(TAG,v.getId()+"");
                callService();
            }
        });
    }
    // This is your ViewHolder class that helps to populate data to the view
    public class AdapterHolder extends RecyclerView.ViewHolder {
        private TextView tvOffersDollar, tvOffersReject, tvOffersAccept;
        public AdapterHolder(View itemView) {
            super(itemView);
            tvOffersDollar = itemView.findViewById(R.id.text_offers_dollar);
            tvOffersReject = itemView.findViewById(R.id.tv_offers_reject);
            tvOffersAccept = itemView.findViewById(R.id.tv_offers_accept);
        }
        public void setOfferDollar(String dollar) {
            tvOffersDollar.setText("$ "+dollar);
        }
    }
    private void callService(){
        ConstantsApi.FLAG_API_NAME = ConstantsApi.FLAG_API_OFFERS_ACCEPT_REJECT;
        Intent serviceIntent = new Intent(mContext, ApiService.class);
        mContext.startService(serviceIntent);
    }
}

