package com.concatsys.tradein.tradein_plugin.adapter;

import android.content.Context;
import android.content.Intent;
import android.graphics.Color;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.cardview.widget.CardView;
import androidx.recyclerview.widget.DiffUtil;
import androidx.recyclerview.widget.ListAdapter;
import androidx.recyclerview.widget.RecyclerView;

import com.concatsys.tradein.tradein_plugin.R;
import com.concatsys.tradein.tradein_plugin.activity.ConstantsActivity;
import com.concatsys.tradein.tradein_plugin.activity.MessageChatActivity;
import com.concatsys.tradein.tradein_plugin.activity.OffersActivity;
import com.concatsys.tradein.tradein_plugin.activity.ProfileStatusActivity;
import com.concatsys.tradein.tradein_plugin.db.ConstantsDB;
import com.concatsys.tradein.tradein_plugin.db.DBVehiclesModel;
import com.concatsys.tradein.tradein_plugin.logs.LoggerTradeIn;

public class DBVehiclesAdapter extends ListAdapter<DBVehiclesModel, DBVehiclesAdapter.ViewHolder> {
    Context mContext;
    private String TAG = getClass().getSimpleName();
    //creating a variable for on item click listner.
    private OnItemClickListener itemClickListener;

    //creating a constructor class for our adapter class.
    public DBVehiclesAdapter() {
        super(DIFF_CALLBACK);
    }

    //creating a call back for item of recycler view.
    private static final DiffUtil.ItemCallback<DBVehiclesModel> DIFF_CALLBACK = new DiffUtil.ItemCallback<DBVehiclesModel>() {
        @Override
        public boolean areItemsTheSame(DBVehiclesModel oldItem, DBVehiclesModel newItem) {
            return oldItem.getVehicle_id() == newItem.getVehicle_id();
        }

        @Override
        public boolean areContentsTheSame(DBVehiclesModel oldItemDBVehiclesModel, DBVehiclesModel newItemDBVehiclesModel) {
            //below line is to check the  name, description and  duration.
            return oldItemDBVehiclesModel.getVehicle_year().equals(newItemDBVehiclesModel.getVehicle_make()) &&
                    oldItemDBVehiclesModel.getVehicle_model().equals(newItemDBVehiclesModel.getVehicle_trim()) &&
                    oldItemDBVehiclesModel.getVehicle_mileage().equals(newItemDBVehiclesModel.getVehicle_vin());
        }
    };

    @NonNull
    @Override
    public ViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
        //below line is use to inflate our layout file for each item of our recycler view.
        View item = LayoutInflater.from(parent.getContext())
                .inflate(R.layout.view_item_db_vehicles, parent, false);
        mContext = parent.getContext();
        return new ViewHolder(item);
    }

    @Override
    public void onBindViewHolder(@NonNull ViewHolder holder, int position) {
        //below line of code is use to set data to each item of our recycler view.
        DBVehiclesModel model = getValuesInAt(position);
//        holder.tvMyVehicleYear.setText(model.getVehicle_id() +" - "+model.getVehicle_year());
        holder.tvMyVehicleYear.setText(model.getVehicle_year()+"");
//        holder.tvMyVehicleMake.setText(model.getVehicle_make()+"");
        holder.tvMyVehicleMake.setText(model.getVehicle_make_name()+"");
//        holder.tvMyVehicleModel.setText(model.getVehicle_model()+"");
        holder.tvMyVehicleModel.setText(model.getVehicle_model_name()+"");
        holder.tvMyVehicleTrim.setText(model.getVehicle_trim()+"");
        int vehicleInfoPercentage = (int) Math.round(model.getVehicle_info_percentage());
//        holder.tvMyVehiclePercent.setText(model.getVehicle_info_percentage()+"");
        holder.tvMyVehiclePercent.setText(vehicleInfoPercentage+"");

//        holder.tvMyVehicleTrim.setText(model.getVehicle_flag()+"");
//        FrameLayout.LayoutParams layoutParams = new FrameLayout.LayoutParams(FrameLayout.LayoutParams.MATCH_PARENT, FrameLayout.LayoutParams.WRAP_CONTENT);
        CardView.LayoutParams layoutParams = new CardView.LayoutParams(
                CardView.LayoutParams.WRAP_CONTENT, CardView.LayoutParams.WRAP_CONTENT);

        if(model.getVehicle_flag().equals("gone")){
            layoutParams.setMargins(ConstantsActivity.CARD_MARGIN_ZERO, ConstantsActivity.CARD_MARGIN_ZERO,ConstantsActivity.CARD_MARGIN_ZERO, ConstantsActivity.CARD_MARGIN_ZERO);
            holder.lytMyVehicles.setVisibility(View.GONE);
        }else{
            layoutParams.setMargins(ConstantsActivity.CARD_MARGIN, ConstantsActivity.CARD_MARGIN,ConstantsActivity.CARD_MARGIN, ConstantsActivity.CARD_MARGIN);
            holder.lytMyVehicles.setVisibility(View.VISIBLE);
        }
        holder.cvMyVehicles.setLayoutParams(layoutParams);
    }

    //creating a method to get  model for a specific position.
    public DBVehiclesModel getValuesInAt(int position) {
        return getItem(position);
    }

    public class ViewHolder extends RecyclerView.ViewHolder {
        //view holder class to create a variable for each view.
        TextView tvMyVehicleYear, tvMyVehicleMake, tvMyVehicleModel, tvMyVehicleTrim, tvMyVehiclePercent;
        ImageView ivMyVehicleEdit, ivMyVehicleOffers, ivMyVehicleChat;
        LinearLayout lytMyVehicles;
        CardView cvMyVehicles;
        ViewHolder(@NonNull View itemView) {
            super(itemView);
            //initializing each view of our recycler view.
            tvMyVehicleYear = itemView.findViewById(R.id.text_my_vehicle_year);
            tvMyVehicleYear.setTextColor(Color.BLUE);
            tvMyVehicleMake = itemView.findViewById(R.id.text_my_vehicle_make);
            tvMyVehicleModel = itemView.findViewById(R.id.text_my_vehicle_model);
            tvMyVehicleTrim = itemView.findViewById(R.id.text_my_vehicle_trim);
            ivMyVehicleEdit = itemView.findViewById(R.id.iv_my_vehicle_edit);
            ivMyVehicleOffers = itemView.findViewById(R.id.iv_my_vehicle_offers);
            ivMyVehicleChat = itemView.findViewById(R.id.iv_my_vehicle_chat);
            lytMyVehicles = itemView.findViewById(R.id.lyt_my_vehicles);
            cvMyVehicles = itemView.findViewById(R.id.cv_my_vehicles);
            tvMyVehiclePercent = itemView.findViewById(R.id.tv_my_vehicle_percent);

            ivMyVehicleEdit.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    int position = getAdapterPosition();
                    int dbListPosition = position + 1;
                    openProfileStatus(dbListPosition);
                }
            });
            ivMyVehicleChat.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    openMessages();
                }
            });
            ivMyVehicleOffers.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    openOffers();
                }
            });
            //adding on click listner for each item of recycler view.
            /*itemView.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    //inside on click listner we are passing position to our item of recycler view.
                    int position = getAdapterPosition();
                    if (itemClickListener != null && position != RecyclerView.NO_POSITION) {
                        itemClickListener.onItemClick(getItem(position));
                    }
                }
            });*/

        }
    }
    private void openProfileStatus(int positionDB){
        ConstantsActivity.ACTIVITY_UPDATE_FLAG = ConstantsActivity.ACTIVITY_UPDATE_FLAG_DB;
        ConstantsDB.dbVehicleIndex = positionDB;
        ConstantsDB.dbUserIndex = positionDB;
        LoggerTradeIn.e(TAG,ConstantsDB.dbVehicleIndex+"");
        ConstantsActivity.flagUpdateEdit = true;
        Intent intent = new Intent(mContext, ProfileStatusActivity.class);
        mContext.startActivity(intent);
    }
    private void openOffers(){
        Intent intent = new Intent(mContext, OffersActivity.class);
        mContext.startActivity(intent);
    }
    private void openMessages(){
        Intent intent = new Intent(mContext, MessageChatActivity.class);
        mContext.startActivity(intent);
    }

    public interface OnItemClickListener {
        void onItemClick(DBVehiclesModel model);
    }

    /* On Click */
    public void setOnItemClickListener(OnItemClickListener listener) {
        this.itemClickListener = listener;
    }
}


