package com.concatsys.tradein.tradein_plugin.adapter;

import android.content.Context;
import android.content.Intent;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.cardview.widget.CardView;
import androidx.recyclerview.widget.RecyclerView;

import com.concatsys.tradein.tradein_plugin.R;
import com.concatsys.tradein.tradein_plugin.activity.ConstantsActivity;
import com.concatsys.tradein.tradein_plugin.activity.MessageChatActivity;
import com.concatsys.tradein.tradein_plugin.activity.OffersActivity;
import com.concatsys.tradein.tradein_plugin.activity.ProfileStatusActivity;
import com.concatsys.tradein.tradein_plugin.api.ApiService;
import com.concatsys.tradein.tradein_plugin.api.ConstantsApi;
import com.concatsys.tradein.tradein_plugin.db.ConstantsDB;
import com.concatsys.tradein.tradein_plugin.db.DBOperations;
import com.concatsys.tradein.tradein_plugin.logs.LoggerTradeIn;
import com.concatsys.tradein.tradein_plugin.utils.DateAndTimeUtils;

import java.util.ArrayList;
import java.util.HashMap;

public class MyVehiclesAdapter extends RecyclerView.Adapter<MyVehiclesAdapter.AdapterHolder> {
    // List to store all the contact details
    private String TAG = getClass().getSimpleName();
    private ArrayList<HashMap<String, String>> alHashData;
    private Context mContext;
    private int layoutId;

    // Constructor for the Class
    public MyVehiclesAdapter(ArrayList<HashMap<String, String>> alHashData, Context context, int layoutId) {
        this.alHashData = alHashData;
        this.mContext = context;
        this.layoutId = layoutId;
    }

    // This method creates views for the RecyclerView by inflating the layout
    // Into the viewHolders which helps to display the items in the RecyclerView
    @Override
    public MyVehiclesAdapter.AdapterHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
        LayoutInflater layoutInflater = LayoutInflater.from(parent.getContext());
        // Inflate the layout view you have created for the list rows here
        View view = layoutInflater.inflate(layoutId, parent, false);
        return new MyVehiclesAdapter.AdapterHolder(view);
    }

    @Override
    public int getItemCount() {
        return alHashData == null ? 0 : alHashData.size();
    }

    // This method is called when binding the data to the views being created in RecyclerView
    @Override
    public void onBindViewHolder(@NonNull MyVehiclesAdapter.AdapterHolder holder, final int position) {
        // Set the data to the views here
//        holder.setYear(alHashData.get(position).get(ConstantsApi.KEYS_GET_VEHICLES[4]));
        holder.tvMyVehicleYear.setText(alHashData.get(position).get(ConstantsApi.KEYS_GET_VEHICLES[4]) + "");
        holder.tvMyVehicleMake.setText(alHashData.get(position).get(ConstantsApi.KEYS_GET_VEHICLES[26]) + "");
        holder.tvMyVehicleModel.setText(alHashData.get(position).get(ConstantsApi.KEYS_GET_VEHICLES[27]) + "");
        holder.tvMyVehicleTrim.setText(alHashData.get(position).get(ConstantsApi.KEYS_GET_VEHICLES[7]) + "");
        holder.tvMyVehicleYear.setId(position);
        /*holder.tvMyVehicleYear.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                LoggerTradeIn.e(TAG,v.getId()+"");
            }
        });*/

        CardView.LayoutParams layoutParams = new CardView.LayoutParams(
                CardView.LayoutParams.WRAP_CONTENT, CardView.LayoutParams.WRAP_CONTENT);
        layoutParams.setMargins(ConstantsActivity.CARD_MARGIN, ConstantsActivity.CARD_MARGIN,ConstantsActivity.CARD_MARGIN, ConstantsActivity.CARD_MARGIN);
        holder.cvMyVehicles.setLayoutParams(layoutParams);
    }

    // This is your ViewHolder class that helps to populate data to the view
    public class AdapterHolder extends RecyclerView.ViewHolder {
        TextView tvMyVehicleYear, tvMyVehicleMake, tvMyVehicleModel, tvMyVehicleTrim, tvMyVehiclePercent;
        ImageView ivMyVehicleEdit, ivMyVehicleOffers, ivMyVehicleChat, ivMyVehiclePercent;
        LinearLayout lytMyVehicles;
        CardView cvMyVehicles;
        public AdapterHolder(View itemView) {
            super(itemView);
            tvMyVehicleYear = itemView.findViewById(R.id.text_my_vehicle_year);
            tvMyVehicleMake = itemView.findViewById(R.id.text_my_vehicle_make);
            tvMyVehicleModel = itemView.findViewById(R.id.text_my_vehicle_model);
            tvMyVehicleTrim = itemView.findViewById(R.id.text_my_vehicle_trim);
            ivMyVehicleEdit = itemView.findViewById(R.id.iv_my_vehicle_edit);
            ivMyVehicleOffers = itemView.findViewById(R.id.iv_my_vehicle_offers);
            ivMyVehicleChat = itemView.findViewById(R.id.iv_my_vehicle_chat);
            lytMyVehicles = itemView.findViewById(R.id.lyt_my_vehicles);
            cvMyVehicles = itemView.findViewById(R.id.cv_my_vehicles);
            ivMyVehiclePercent = itemView.findViewById(R.id.iv_my_vehicle_percent);
            tvMyVehiclePercent = itemView.findViewById(R.id.tv_my_vehicle_percent);

            ivMyVehiclePercent.setImageResource(R.drawable.shape_circle_green);
            tvMyVehiclePercent.setText(mContext.getResources().getString(R.string._100_completed));

            /*lytMyVehicles.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    int position = getAdapterPosition();
                    LoggerTradeIn.e(TAG, position + " @89");
                    LoggerTradeIn.e(TAG, ConstantsApi.LEAD_KEY_UP_URL + " @89");
                    LoggerTradeIn.e(TAG, ConstantsApi.VEHICLE_KEY_UP_URL + " @89");
                    getVehicleApi2(position);
                }
            });*/

            ivMyVehicleEdit.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    int position = getAdapterPosition();
                    LoggerTradeIn.e(TAG, position + " @89");
                    LoggerTradeIn.e(TAG, ConstantsApi.LEAD_KEY_UP_URL + " @89");
                    LoggerTradeIn.e(TAG, ConstantsApi.VEHICLE_KEY_UP_URL + " @89");
                    getVehicleApi2(position);
                }
            });

            ivMyVehicleChat.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    openMessages();
                }
            });
            ivMyVehicleOffers.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    openOffers();
                }
            });
        }

        public void setYear(String year) {
            tvMyVehicleYear.setText(year);
        }
    }

    private void getVehicleApi2(int position) {
        ConstantsApi.VEHICLE_KEY_UP_URL = ConstantsApi.alHMMYVEHICLES.get(position).get(ConstantsApi.KEYS_VEHICLE_ONE_ARRAY[2]) + "";
        LoggerTradeIn.e(TAG, ConstantsApi.VEHICLE_KEY_UP_URL + " @**VKey134");
        ConstantsApi.FLAG_API_NAME = ConstantsApi.FLAG_API_GET_ONE_VEHICLE;
        Intent serviceIntent = new Intent(mContext, ApiService.class);
        mContext.startService(serviceIntent);
//        openProfileStatus2(position);
    }

    DBOperations dbOperations;
    private void openProfileStatus2(int position) {
        ConstantsActivity.ACTIVITY_UPDATE_FLAG = ConstantsActivity.ACTIVITY_UPDATE_FLAG_API;
        Intent intent = new Intent(mContext, ProfileStatusActivity.class);
        mContext.startActivity(intent);

        dbOperations = DBOperations.getInstance();
        ConstantsDB.dbVehicleIndex = dbOperations.getMyVehicleSize2(mContext) + 1;
        ConstantsDB.dbUserIndex = dbOperations.getMyUserSize2(mContext) + 1;
        ConstantsDB.dbMediaIndex = dbOperations.getMyMediaSize2(mContext) + 1;
        LoggerTradeIn.e(TAG, ConstantsDB.dbVehicleIndex + " @148");

        dbOperations.insertVehicle(mContext, ConstantsDB.dbVehicleIndex, "1", false, 0.0, "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", false, false, "", "", "", DateAndTimeUtils.getDateTimeFormat(), DateAndTimeUtils.getDateTimeFormat(), "gone");
        dbOperations.insertVehicleMedia(mContext, ConstantsDB.dbMediaIndex, "1", "1", null, "", "", false, DateAndTimeUtils.getDateTimeFormat(), DateAndTimeUtils.getDateTimeFormat());
        dbOperations.insertUsers(mContext, "", "", "", "", "", "", "", "", DateAndTimeUtils.getDateTimeFormat(), DateAndTimeUtils.getDateTimeFormat());
    }

    private void openProfileStatus(int positionDB) {
        ConstantsDB.dbVehicleIndex = positionDB;
        ConstantsDB.dbUserIndex = positionDB;
        LoggerTradeIn.e(TAG, ConstantsDB.dbVehicleIndex + "");
        ConstantsActivity.flagUpdateEdit = true;
        Intent intent = new Intent(mContext, ProfileStatusActivity.class);
        mContext.startActivity(intent);
    }

    private void openOffers() {
        Intent intent = new Intent(mContext, OffersActivity.class);
        mContext.startActivity(intent);
    }

    private void openMessages() {
        Intent intent = new Intent(mContext, MessageChatActivity.class);
        mContext.startActivity(intent);
    }
}
