package com.concatsys.tradein.tradein_plugin.db;

import android.app.Application;
import android.os.AsyncTask;

import androidx.lifecycle.LiveData;

import java.util.List;

public class DBSdkRepository {
    //below line is the create a variable for dao and list for all .
    private DBSdkDAO dbDAO;
    private LiveData<List<DBSdkModel>> dbRoomModelList;
    //creating a constructor for our variables and passing the variables to it.
    public DBSdkRepository(Application application) {
        DataBaseRoomInstance database = DataBaseRoomInstance.getInstance(application);
        dbDAO = database.DaoDBSdk();
        dbRoomModelList = dbDAO.getAllTableValues();
    }

    //creating a method to insert the data to our database.
    public void insert(DBSdkModel model) {
        new InsertDBAsyncTask(dbDAO).execute(model);
    }

    //creating a method to update data in database.
    public void update(DBSdkModel model) {
        new UpdateDBAsyncTask(dbDAO).execute(model);
    }

    //creating a method to delete the data in our database.
    public void delete(DBSdkModel model) {
        new DeleteDBAsyncTask(dbDAO).execute(model);
    }

    //below is the method to delete all the .
    public void deleteAllValues() {
        new DeleteAllDBAsyncTask(dbDAO).execute();
    }

    //below method is to read all the .
    public LiveData<List<DBSdkModel>> getAllValues() {
        return dbRoomModelList;
    }

    //we are creating a async task method to insert new .
    private static class InsertDBAsyncTask extends AsyncTask<DBSdkModel, Void, Void> {
        private DBSdkDAO dbInsertDAO;

        private InsertDBAsyncTask(DBSdkDAO dbInsertDAO) {
            this.dbInsertDAO = dbInsertDAO;
        }

        @Override
        protected Void doInBackground(DBSdkModel... model) {
            //below line is use to insert our model in dao.
            dbInsertDAO.insert(model[0]);
            return null;
        }
    }

    //we are creating a async task method to update our .
    private static class UpdateDBAsyncTask extends AsyncTask<DBSdkModel, Void, Void> {
        private DBSdkDAO dbUpdateDAO;

        private UpdateDBAsyncTask(DBSdkDAO dbUpdateDAO) {
            this.dbUpdateDAO = dbUpdateDAO;
        }

        @Override
        protected Void doInBackground(DBSdkModel... models) {
            //below line is use to update our model in dao.
            dbUpdateDAO.update(models[0]);
            return null;
        }
    }

    //we are creating a async task method to delete .
    private static class DeleteDBAsyncTask extends AsyncTask<DBSdkModel, Void, Void> {
        private DBSdkDAO dbDeleteDAO;

        private DeleteDBAsyncTask(DBSdkDAO dbDeleteDAO) {
            this.dbDeleteDAO = dbDeleteDAO;
        }

        @Override
        protected Void doInBackground(DBSdkModel... models) {
            //below line is use to delete our  model in dao.
            dbDeleteDAO.delete(models[0]);
            return null;
        }
    }

    //we are creating a async task method to delete all .
    private static class DeleteAllDBAsyncTask extends AsyncTask<Void, Void, Void> {
        private DBSdkDAO dbDeleteAllDAO;

        private DeleteAllDBAsyncTask(DBSdkDAO dbDeleteAllDAO) {
            this.dbDeleteAllDAO = dbDeleteAllDAO;
        }

        @Override
        protected Void doInBackground(Void... voids) {
            //on below line calling method to delete all .
            dbDeleteAllDAO.deleteAllTableValues();
            return null;
        }
    }
}
