package com.concatsys.tradein.tradein_plugin.db;

import android.app.Application;
import android.os.AsyncTask;

import androidx.lifecycle.LiveData;

import java.util.List;

public class DBUsersRepository {
    //below line is the create a variable for dao and list for all .
    private DBUsersDAO dbDAO;
    private LiveData<List<DBUsersModel>> dbRoomModelList;
    //creating a constructor for our variables and passing the variables to it.
    public DBUsersRepository(Application application) {
        DataBaseRoomInstance database = DataBaseRoomInstance.getInstance(application);
        dbDAO = database.DaoUsers();
        dbRoomModelList = dbDAO.getAllTableValues();
    }

    //creating a method to insert the data to our database.
    public void insert(DBUsersModel model) {
        new InsertDBAsyncTask(dbDAO).execute(model);
    }

    //creating a method to update data in database.
    public void update(DBUsersModel model) {
        new UpdateDBAsyncTask(dbDAO).execute(model);
    }

    //creating a method to delete the data in our database.
    public void delete(DBUsersModel model) {
        new DeleteDBAsyncTask(dbDAO).execute(model);
    }

    //below is the method to delete all the .
    public void deleteAllValues() {
        new DeleteAllDBAsyncTask(dbDAO).execute();
    }

    //below method is to read all the .
    public LiveData<List<DBUsersModel>> getAllValues() {
        return dbRoomModelList;
    }

    //we are creating a async task method to insert new .
    private static class InsertDBAsyncTask extends AsyncTask<DBUsersModel, Void, Void> {
        private DBUsersDAO dbInsertDAO;

        private InsertDBAsyncTask(DBUsersDAO dbInsertDAO) {
            this.dbInsertDAO = dbInsertDAO;
        }

        @Override
        protected Void doInBackground(DBUsersModel... model) {
            //below line is use to insert our model in dao.
            dbInsertDAO.insert(model[0]);
            return null;
        }
    }

    //we are creating a async task method to update our .
    private static class UpdateDBAsyncTask extends AsyncTask<DBUsersModel, Void, Void> {
        private DBUsersDAO dbUpdateDAO;

        private UpdateDBAsyncTask(DBUsersDAO dbUpdateDAO) {
            this.dbUpdateDAO = dbUpdateDAO;
        }

        @Override
        protected Void doInBackground(DBUsersModel... models) {
            //below line is use to update our model in dao.
            dbUpdateDAO.update(models[0]);
            return null;
        }
    }

    //we are creating a async task method to delete .
    private static class DeleteDBAsyncTask extends AsyncTask<DBUsersModel, Void, Void> {
        private DBUsersDAO dbDeleteDAO;

        private DeleteDBAsyncTask(DBUsersDAO dbDeleteDAO) {
            this.dbDeleteDAO = dbDeleteDAO;
        }

        @Override
        protected Void doInBackground(DBUsersModel... models) {
            //below line is use to delete our  model in dao.
            dbDeleteDAO.delete(models[0]);
            return null;
        }
    }

    //we are creating a async task method to delete all .
    private static class DeleteAllDBAsyncTask extends AsyncTask<Void, Void, Void> {
        private DBUsersDAO dbDeleteAllDAO;

        private DeleteAllDBAsyncTask(DBUsersDAO dbDeleteAllDAO) {
            this.dbDeleteAllDAO = dbDeleteAllDAO;
        }

        @Override
        protected Void doInBackground(Void... voids) {
            //on below line calling method to delete all .
            dbDeleteAllDAO.deleteAllTableValues();
            return null;
        }
    }
}
