package com.concatsys.tradein.tradein_plugin.db;

import android.app.Application;
import android.os.AsyncTask;
import android.util.Log;

import androidx.lifecycle.LiveData;

import java.util.List;

public class DBVehicleMediaRepository {
    //below line is the create a variable for dao and list for all .
    private DBVehicleMediaDAO dbDAO;
    private LiveData<List<DBVehicleMediaModel>> dbRoomModelList;
    //creating a constructor for our variables and passing the variables to it.
    public DBVehicleMediaRepository(Application application) {
        DataBaseRoomInstance database = DataBaseRoomInstance.getInstance(application);
        dbDAO = database.DaoDBVehicleMedia();
        dbRoomModelList = dbDAO.getAllTableValues();
    }

    //creating a method to insert the data to our database.
    public void insert(DBVehicleMediaModel model) {
        new InsertDBAsyncTask(dbDAO).execute(model);
    }

    //creating a method to update data in database.
    public void update(DBVehicleMediaModel model) {
        new UpdateDBAsyncTask(dbDAO).execute(model);
    }

    //creating a method to delete the data in our database.
    public void delete(DBVehicleMediaModel model) {
        new DeleteDBAsyncTask(dbDAO).execute(model);
    }

    //below is the method to delete all the .
    public void deleteAllValues() {
        new DeleteAllDBAsyncTask(dbDAO).execute();
    }



    public void updateVehicleMedia(int media_vehicle_id, String media_guid, String media_url, String media_type, String media_issequence, boolean media_is_uploaded) {
        new UpdateDBVehicleMedia(dbDAO, media_vehicle_id, media_guid, media_url, media_type, media_issequence,media_is_uploaded).execute();
    }

    //below method is to read all the .
    public LiveData<List<DBVehicleMediaModel>> getAllValues() {
        return dbRoomModelList;
    }

    //we are creating a async task method to insert new .
    private static class InsertDBAsyncTask extends AsyncTask<DBVehicleMediaModel, Void, Void> {
        private DBVehicleMediaDAO dbInsertDAO;

        private InsertDBAsyncTask(DBVehicleMediaDAO dbInsertDAO) {
            this.dbInsertDAO = dbInsertDAO;
        }

        @Override
        protected Void doInBackground(DBVehicleMediaModel... model) {
            //below line is use to insert our model in dao.
            dbInsertDAO.insert(model[0]);
            return null;
        }
    }

    //we are creating a async task method to update our .
    private static class UpdateDBAsyncTask extends AsyncTask<DBVehicleMediaModel, Void, Void> {
        private DBVehicleMediaDAO dbUpdateDAO;

        private UpdateDBAsyncTask(DBVehicleMediaDAO dbUpdateDAO) {
            this.dbUpdateDAO = dbUpdateDAO;
        }

        @Override
        protected Void doInBackground(DBVehicleMediaModel... models) {
            //below line is use to update our model in dao.
            dbUpdateDAO.update(models[0]);
            return null;
        }
    }

    //we are creating a async task method to delete .
    private static class DeleteDBAsyncTask extends AsyncTask<DBVehicleMediaModel, Void, Void> {
        private DBVehicleMediaDAO dbDeleteDAO;

        private DeleteDBAsyncTask(DBVehicleMediaDAO dbDeleteDAO) {
            this.dbDeleteDAO = dbDeleteDAO;
        }

        @Override
        protected Void doInBackground(DBVehicleMediaModel... models) {
            //below line is use to delete our  model in dao.
            dbDeleteDAO.delete(models[0]);
            return null;
        }
    }

    //we are creating a async task method to delete all .
    private static class DeleteAllDBAsyncTask extends AsyncTask<Void, Void, Void> {
        private DBVehicleMediaDAO dbDeleteAllDAO;

        private DeleteAllDBAsyncTask(DBVehicleMediaDAO dbDeleteAllDAO) {
            this.dbDeleteAllDAO = dbDeleteAllDAO;
        }

        @Override
        protected Void doInBackground(Void... voids) {
            //on below line calling method to delete all .
            dbDeleteAllDAO.deleteAllTableValues();
            return null;
        }
    }

    //    db media
//we are creating a async task method to update our .
    private static class UpdateDBVehicleMedia extends AsyncTask<Void, Void, Void> {
        private DBVehicleMediaDAO dbUpdateDAO;
        private String media_guid, media_url, media_type, media_issequence,media_created_at,media_modified_at;
        int media_vehicle_id;
        boolean media_is_uploaded;

        private UpdateDBVehicleMedia(DBVehicleMediaDAO dbUpdateDAO, int media_vehicle_id,
                                     String media_guid, String media_url, String media_type, String media_issequence, boolean media_is_uploaded) {
            this.dbUpdateDAO = dbUpdateDAO;
            this.media_vehicle_id = media_vehicle_id;
            this.media_guid = media_guid;
            this.media_url = media_url;
            this.media_type = media_type;
            this.media_issequence = media_issequence;
            this.media_is_uploaded = media_is_uploaded;
        }

        @Override
        protected Void doInBackground(Void... voids) {
            //below line is use to update our model in dao.
//            dbUpdateDAO.update(models[0]);
            dbUpdateDAO.updateVehicleMedia(media_vehicle_id, media_guid, media_url, media_type, media_issequence,media_is_uploaded);
            return null;
        }
    }
//

}
