package com.concatsys.tradein.tradein_plugin.db;

import android.app.Application;
import android.os.AsyncTask;

import androidx.lifecycle.LiveData;

import com.concatsys.tradein.tradein_plugin.logs.LoggerTradeIn;

import java.util.List;

public class DBVehiclesRepository {
    //below line is the create a variable for dao and list for all .
    private DBVehiclesDAO dbDAO;
    private LiveData<List<DBVehiclesModel>> dbRoomModelList;

    //creating a constructor for our variables and passing the variables to it.
    public DBVehiclesRepository(Application application) {
        DataBaseRoomInstance database = DataBaseRoomInstance.getInstance(application);
        dbDAO = database.DaoVehicle();
        dbRoomModelList = dbDAO.getAllTableValues();
    }

    //creating a method to insert the data to our database.
    public void insert(DBVehiclesModel model) {
        new InsertDBAsyncTask(dbDAO).execute(model);
    }

    //creating a method to update data in database.
    public void update(DBVehiclesModel model) {
        new UpdateDBAsyncTask(dbDAO).execute(model);
    }

    public void updateVI1(int vehicle_id, int vehicle_user_id, String vehicle_guid, boolean vehicle_is_uploaded, double vehicle_info_percentage, String vehicle_year, String vehicle_make, String vehicle_make_name, String vehicle_model, String vehicle_model_name, String vehicle_trim, String vehicle_mileage, String vehicle_vin, String vehicle_exterior_color) {
        new UpdateDBVehicleInfo1(dbDAO, vehicle_id, vehicle_user_id, vehicle_guid, vehicle_is_uploaded, vehicle_info_percentage, vehicle_year, vehicle_make, vehicle_make_name, vehicle_model, vehicle_model_name, vehicle_trim, vehicle_mileage, vehicle_vin, vehicle_exterior_color).execute();
    }

    public void updateVI2(int vehicle_id, int vehicle_user_id, String vehicle_guid, boolean vehicle_is_uploaded, double vehicle_info_percentage,
                          String vehicle_interior_color, String vehicle_transmission, String vehicle_drivetrain, String vehicle_body_style, String vehicle_engine, String vehicle_seat_type) {
        new UpdateDBVehicleInfo2(dbDAO, vehicle_id, vehicle_user_id, vehicle_guid, vehicle_is_uploaded, vehicle_info_percentage, vehicle_interior_color, vehicle_transmission, vehicle_drivetrain, vehicle_body_style, vehicle_engine, vehicle_seat_type).execute();
    }

    public void updateVehicleOptions(int vehicle_id, int vehicle_user_id, String vehicle_guid, boolean vehicle_is_uploaded, double vehicle_info_percentage,
                                     String vehicle_comment, String vehicle_options, String vehicle_packages) {
        new UpdateDBVehicleOptions(dbDAO, vehicle_id, vehicle_user_id, vehicle_guid, vehicle_is_uploaded, vehicle_info_percentage, vehicle_comment, vehicle_options, vehicle_packages).execute();
    }

    public void updateVehicleCondition(int vehicle_id, int vehicle_user_id, String vehicle_guid, boolean vehicle_is_uploaded, double vehicle_info_percentage,
                                       String vehicle_interior_condition, String vehicle_exterior_condition, String vehicle_smoked, String vehicle_accident, String vehicle_comment) {
        new UpdateDBVehicleConditions(dbDAO, vehicle_id, vehicle_user_id, vehicle_guid, vehicle_is_uploaded, vehicle_info_percentage, vehicle_interior_condition,vehicle_exterior_condition,vehicle_smoked,vehicle_accident,vehicle_comment).execute();
    }
    public void updateVehicleFlag(int vehicle_id, String vehicle_flag) {
        new UpdateDBVehicleFlag(dbDAO, vehicle_id, vehicle_flag).execute();
    }

    public void updateVehiclePercentage(int vehicle_id, double vehicle_percentage) {
        new UpdateDBVehiclePercentage(dbDAO, vehicle_id, vehicle_percentage).execute();
    }

    //creating a method to update data in database.
    /*public void updateVehicleInfo(DBVehiclesModel model) {
        new UpdateDBAsyncTaskVehicleInfo(dbDAO).execute(model);
    }*/

    //creating a method to delete the data in our database.
    public void delete(DBVehiclesModel model) {
        new DeleteDBAsyncTask(dbDAO).execute(model);
    }

    //below is the method to delete all the .
    public void deleteAllValues() {
        new DeleteAllDBAsyncTask(dbDAO).execute();
    }

    //below method is to read all the .
    public LiveData<List<DBVehiclesModel>> getAllValues() {
        return dbRoomModelList;
    }

    //we are creating a async task method to insert new .
    private static class InsertDBAsyncTask extends AsyncTask<DBVehiclesModel, Void, Void> {
        private DBVehiclesDAO dbInsertDAO;

        private InsertDBAsyncTask(DBVehiclesDAO dbInsertDAO) {
            this.dbInsertDAO = dbInsertDAO;
        }

        @Override
        protected Void doInBackground(DBVehiclesModel... model) {
            //below line is use to insert our model in dao.
            LoggerTradeIn.e("getVehicle_id",model[0].getVehicle_id()+"");
            dbInsertDAO.insert(model[0]);
            return null;
        }
    }

    //we are creating a async task method to update our .
    private static class UpdateDBAsyncTask extends AsyncTask<DBVehiclesModel, Void, Void> {
        private DBVehiclesDAO dbUpdateDAO;

        private UpdateDBAsyncTask(DBVehiclesDAO dbUpdateDAO) {
            this.dbUpdateDAO = dbUpdateDAO;
        }

        @Override
        protected Void doInBackground(DBVehiclesModel... models) {
            //below line is use to update our model in dao.
            dbUpdateDAO.update(models[0]);
//            dbUpdateDAO.updateTour();
            return null;
        }
    }

    //we are creating a async task method to update our .
    private static class UpdateDBVehicleInfo1 extends AsyncTask<Void, Void, Void> {
        private DBVehiclesDAO dbUpdateDAO;
        private String vehicle_guid, vehicle_year, vehicle_make, vehicle_make_name, vehicle_model, vehicle_model_name, vehicle_trim, vehicle_mileage, vehicle_vin, vehicle_exterior_color;
        int vehicle_id, vehicle_user_id;
        boolean vehicle_is_uploaded;
        double vehicle_info_percentage;

        private UpdateDBVehicleInfo1(DBVehiclesDAO dbUpdateDAO, int vehicle_id, int vehicle_user_id, String vehicle_guid, boolean vehicle_is_uploaded, double vehicle_info_percentage, String vehicle_year, String vehicle_make, String vehicle_make_name, String vehicle_model, String vehicle_model_name, String vehicle_trim, String vehicle_mileage, String vehicle_vin, String vehicle_exterior_color) {
            this.dbUpdateDAO = dbUpdateDAO;
            this.vehicle_id = vehicle_id;
            this.vehicle_user_id = vehicle_user_id;
            this.vehicle_guid = vehicle_guid;
            this.vehicle_is_uploaded = vehicle_is_uploaded;
            this.vehicle_info_percentage = vehicle_info_percentage;
            this.vehicle_year = vehicle_year;
            this.vehicle_make = vehicle_make;
            this.vehicle_make_name = vehicle_make_name;
            this.vehicle_model = vehicle_model;
            this.vehicle_model_name = vehicle_model_name;
            this.vehicle_trim = vehicle_trim;
            this.vehicle_mileage = vehicle_mileage;
            this.vehicle_vin = vehicle_vin;
            this.vehicle_exterior_color = vehicle_exterior_color;
        }

        @Override
        protected Void doInBackground(Void... voids) {
            //below line is use to update our model in dao.
//            dbUpdateDAO.update(models[0]);
            dbUpdateDAO.updateVI1(vehicle_id, vehicle_year, vehicle_make, vehicle_make_name, vehicle_model, vehicle_model_name, vehicle_trim, vehicle_mileage, vehicle_vin, vehicle_exterior_color);
            return null;
        }
    }

    //we are creating a async task method to update our .
    private static class UpdateDBVehicleInfo2 extends AsyncTask<Void, Void, Void> {
        private DBVehiclesDAO dbUpdateDAO;
        private String vehicle_guid, vehicle_interior_color, vehicle_transmission, vehicle_drivetrain, vehicle_body_style, vehicle_engine, vehicle_seat_type;
        int vehicle_id, vehicle_user_id;
        boolean vehicle_is_uploaded;
        double vehicle_info_percentage;

        private UpdateDBVehicleInfo2(DBVehiclesDAO dbUpdateDAO, int vehicle_id, int vehicle_user_id, String vehicle_guid, boolean vehicle_is_uploaded, double vehicle_info_percentage,
                                     String vehicle_interior_color, String vehicle_transmission, String vehicle_drivetrain, String vehicle_body_style, String vehicle_engine, String vehicle_seat_type) {
            this.dbUpdateDAO = dbUpdateDAO;
            this.vehicle_id = vehicle_id;
            this.vehicle_user_id = vehicle_user_id;
            this.vehicle_guid = vehicle_guid;
            this.vehicle_is_uploaded = vehicle_is_uploaded;
            this.vehicle_info_percentage = vehicle_info_percentage;
            this.vehicle_interior_color = vehicle_interior_color;
            this.vehicle_transmission = vehicle_transmission;
            this.vehicle_drivetrain = vehicle_drivetrain;
            this.vehicle_body_style = vehicle_body_style;
            this.vehicle_engine = vehicle_engine;
            this.vehicle_seat_type = vehicle_seat_type;
        }

        @Override
        protected Void doInBackground(Void... voids) {
            //below line is use to update our model in dao.
//            dbUpdateDAO.update(models[0]);
            dbUpdateDAO.updateVI2(vehicle_id, vehicle_interior_color, vehicle_transmission, vehicle_drivetrain, vehicle_body_style, vehicle_engine, vehicle_seat_type);
            return null;
        }
    }

    //    db options
//we are creating a async task method to update our .
    private static class UpdateDBVehicleOptions extends AsyncTask<Void, Void, Void> {
        private DBVehiclesDAO dbUpdateDAO;
        private String vehicle_guid, vehicle_comment, vehicle_options, vehicle_packages;
        int vehicle_id, vehicle_user_id;
        boolean vehicle_is_uploaded;
        double vehicle_info_percentage;

        private UpdateDBVehicleOptions(DBVehiclesDAO dbUpdateDAO, int vehicle_id, int vehicle_user_id, String vehicle_guid, boolean vehicle_is_uploaded, double vehicle_info_percentage,
                                       String vehicle_comment, String vehicle_options, String vehicle_packages) {
            this.dbUpdateDAO = dbUpdateDAO;
            this.vehicle_id = vehicle_id;
            this.vehicle_user_id = vehicle_user_id;
            this.vehicle_guid = vehicle_guid;
            this.vehicle_is_uploaded = vehicle_is_uploaded;
            this.vehicle_info_percentage = vehicle_info_percentage;
            this.vehicle_comment = vehicle_comment;
            this.vehicle_options = vehicle_options;
            this.vehicle_packages = vehicle_packages;
        }

        @Override
        protected Void doInBackground(Void... voids) {
            //below line is use to update our model in dao.
//            dbUpdateDAO.update(models[0]);
            dbUpdateDAO.updateVehicleOptions(vehicle_id, vehicle_comment ,vehicle_options, vehicle_packages);
            return null;
        }
    }


    //    db Conditions
//we are creating a async task method to update our .
    private static class UpdateDBVehicleConditions extends AsyncTask<Void, Void, Void> {
        private DBVehiclesDAO dbUpdateDAO;
        private String vehicle_guid, vehicle_interior_condition, vehicle_exterior_condition, vehicle_smoked, vehicle_accident, vehicle_comment;
        int vehicle_id, vehicle_user_id;
        boolean vehicle_is_uploaded;
        double vehicle_info_percentage;

        private UpdateDBVehicleConditions(DBVehiclesDAO dbUpdateDAO, int vehicle_id, int vehicle_user_id, String vehicle_guid, boolean vehicle_is_uploaded, double vehicle_info_percentage,
                                          String vehicle_interior_condition, String vehicle_exterior_condition, String vehicle_smoked, String vehicle_accident, String vehicle_comment) {
            this.dbUpdateDAO = dbUpdateDAO;
            this.vehicle_id = vehicle_id;
            this.vehicle_user_id = vehicle_user_id;
            this.vehicle_guid = vehicle_guid;
            this.vehicle_is_uploaded = vehicle_is_uploaded;
            this.vehicle_info_percentage = vehicle_info_percentage;
            this.vehicle_interior_condition = vehicle_interior_condition;
            this.vehicle_exterior_condition = vehicle_exterior_condition;
            this.vehicle_smoked = vehicle_smoked;
            this.vehicle_accident = vehicle_accident;
            this.vehicle_comment = vehicle_comment;
        }

        @Override
        protected Void doInBackground(Void... voids) {
            //below line is use to update our model in dao.
//            dbUpdateDAO.update(models[0]);
            boolean bSmoked = false,bAccident = false;
            if(vehicle_smoked.equalsIgnoreCase("yes")){
                bSmoked = true;
            }
            if(vehicle_accident.equalsIgnoreCase("yes")){
                bAccident = true;
            }

            dbUpdateDAO.updateVehicleConditions(vehicle_id, vehicle_interior_condition, vehicle_exterior_condition, bSmoked, bAccident, vehicle_comment);
            return null;
        }
    }

    //    db Flag
//we are creating a async task method to update our .
    private static class UpdateDBVehicleFlag extends AsyncTask<Void, Void, Void> {
        private DBVehiclesDAO dbUpdateDAO;
        private String vehicle_flag;
        int vehicle_id;

        private UpdateDBVehicleFlag(DBVehiclesDAO dbUpdateDAO, int vehicle_id , String vehicle_flag) {
            this.dbUpdateDAO = dbUpdateDAO;
            this.vehicle_id = vehicle_id;
            this.vehicle_flag = vehicle_flag;
        }

        @Override
        protected Void doInBackground(Void... voids) {
            //below line is use to update our model in dao.

            dbUpdateDAO.updateVehicleFlag(vehicle_id, vehicle_flag);
            return null;
        }
    }

    //    db Percentage
//we are creating a async task method to update our .
    private static class UpdateDBVehiclePercentage extends AsyncTask<Void, Void, Void> {
        private DBVehiclesDAO dbUpdateDAO;
        private double vehicle_percentage;
        int vehicle_id;

        private UpdateDBVehiclePercentage(DBVehiclesDAO dbUpdateDAO, int vehicle_id , double vehicle_percentage) {
            this.dbUpdateDAO = dbUpdateDAO;
            this.vehicle_id = vehicle_id;
            this.vehicle_percentage = vehicle_percentage;
        }

        @Override
        protected Void doInBackground(Void... voids) {
            //below line is use to update our model in dao.

            dbUpdateDAO.updateVehiclePercent(vehicle_id, vehicle_percentage);
            return null;
        }
    }
    //we are creating a async task method to update our .
    /*private static class UpdateDBAsyncTaskVehicleInfo extends AsyncTask<DBVehiclesModel, Void, Void> {
        private DBVehiclesDAO dbUpdateDAO;

        private UpdateDBAsyncTaskVehicleInfo(DBVehiclesDAO dbUpdateDAO) {
            this.dbUpdateDAO = dbUpdateDAO;
        }

        @Override
        protected Void doInBackground(DBVehiclesModel... models) {
            //below line is use to update our model in dao.
            dbUpdateDAO.updateVehicleInfo(models[0].getVehicle_year(),models[0].getVehicle_make(),
                    models[0].getVehicle_model(),models[0].getVehicle_trim(),models[0].getVehicle_mileage(),
                    models[0].getVehicle_vin(),models[0].getVehicle_exterior_color());
            return null;
        }
    }*/

    //we are creating a async task method to delete .
    private static class DeleteDBAsyncTask extends AsyncTask<DBVehiclesModel, Void, Void> {
        private DBVehiclesDAO dbDeleteDAO;

        private DeleteDBAsyncTask(DBVehiclesDAO dbDeleteDAO) {
            this.dbDeleteDAO = dbDeleteDAO;
        }

        @Override
        protected Void doInBackground(DBVehiclesModel... models) {
            //below line is use to delete our  model in dao.
            dbDeleteDAO.delete(models[0]);
            return null;
        }
    }

    //we are creating a async task method to delete all .
    private static class DeleteAllDBAsyncTask extends AsyncTask<Void, Void, Void> {
        private DBVehiclesDAO dbDeleteAllDAO;

        private DeleteAllDBAsyncTask(DBVehiclesDAO dbDeleteAllDAO) {
            this.dbDeleteAllDAO = dbDeleteAllDAO;
        }

        @Override
        protected Void doInBackground(Void... voids) {
            //on below line calling method to delete all .
            dbDeleteAllDAO.deleteAllTableValues();
            return null;
        }
    }
}
