package com.concatsys.tradein.tradein_plugin.db;

import android.content.Context;
import android.os.AsyncTask;

import androidx.annotation.NonNull;
import androidx.room.Database;
import androidx.room.Room;
import androidx.room.RoomDatabase;
import androidx.room.TypeConverters;
import androidx.sqlite.db.SupportSQLiteDatabase;

//adding annotation for our databse entities and db version.
@Database(entities = {DBAccountsModel.class, DBRoofTopModel.class,
        DBSdkModel.class, DBUsersModel.class, DBVehicleMediaModel.class
        , DBVehicleOptionsModel.class, DBVehiclesModel.class}
        , version = 1)
@TypeConverters({ArrayListCastConverter.class, ArrayListUriCastConverter.class, DateConverterDB.class})
public abstract class DataBaseRoomInstance extends RoomDatabase {
    //below line is to create instance for our databse class.
    private static DataBaseRoomInstance instance;

    //below line is to create abstract variable for dao.

    public abstract DBUsersDAO DaoUsers();

    public abstract DBRoofTopDAO DaoRoofTop();

    public abstract DBAccountsDAO DaoAccounts();

    public abstract DBVehicleOptionsDAO DaoVehicleOptions();

    public abstract DBVehiclesDAO DaoVehicle();

    public abstract DBVehicleMediaDAO DaoDBVehicleMedia();

    public abstract DBSdkDAO DaoDBSdk();

    //on below line we are getting instance for our database.
    public static synchronized DataBaseRoomInstance getInstance(Context context) {
        //below line is to check if the instance is null or not.
        if (instance == null) {
            //if the instance is null we are creating a new instance
            instance =
                    //for creating a instance for our database we are creating a database builder and passing our database class with our database name.
                    Room.databaseBuilder(context.getApplicationContext(),
                            DataBaseRoomInstance.class, ConstantsDB.DATA_BASE_NAME)
                            .fallbackToDestructiveMigration()
                            .allowMainThreadQueries()
                            .build();
        }
        //after creating an instance we are returning our instance
        return instance;
    }

    //below line is to create a callback for our room database.
    private static Callback roomCallback = new Callback() {
        @Override
        public void onCreate(@NonNull SupportSQLiteDatabase db) {
            super.onCreate(db);
            //this method is called when database is created and below line is to populate our data.
            new PopulateDbAsyncTask(instance).execute();
        }
    };

    //we are creating an async task class to perform task in background.
    private static class PopulateDbAsyncTask extends AsyncTask<Void, Void, Void> {
        PopulateDbAsyncTask(DataBaseRoomInstance instance) {
//            DBUsersDAO DBVehicleInfoOneDao = instance.DaoUsers();
//            DBVehicleInfoOneDao.getAllTableValues();
        }

        @Override
        protected Void doInBackground(Void... voids) {
            return null;
        }
    }
}
