package com.concatsys.tradein.tradein_plugin.logscapture;

import android.Manifest;
import android.annotation.SuppressLint;
import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.content.pm.PackageInfo;
import android.content.pm.PackageManager;
import android.net.Uri;
import android.os.Build;
import android.util.Log;
import android.widget.Toast;

import androidx.core.app.ActivityCompat;
import androidx.core.content.ContextCompat;
import androidx.core.content.FileProvider;

import com.concatsys.tradein.tradein_plugin.R;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.io.InputStreamReader;
import java.text.SimpleDateFormat;
import java.util.Date;

public class LogsCaptureCalls {
    Context mContext;
    private SharedPreferences.Editor logsSharedPrefsEdit;
    private SharedPreferences logsSharedPreferences;

    public void init(Context context) {
        Log.e("LogsCaptureCalls", "init");
        mContext = context;
        logsSharedPreferences = mContext.getSharedPreferences(LogsCaptureUtils.preferencesName, 0);
        logsSharedPrefsEdit = logsSharedPreferences.edit();
    }

    private static final int REQUEST_EXTERNAL_STORAGE = 1;
    private static String[] PERMISSIONS_STORAGE = {
            Manifest.permission.READ_EXTERNAL_STORAGE,
            Manifest.permission.WRITE_EXTERNAL_STORAGE
    };

    public void getPermissionFiles() {
        if (ContextCompat.checkSelfPermission(mContext, Manifest.permission.WRITE_EXTERNAL_STORAGE)
                != PackageManager.PERMISSION_GRANTED || ContextCompat.checkSelfPermission(mContext, Manifest.permission.READ_EXTERNAL_STORAGE)
                != PackageManager.PERMISSION_GRANTED) {
            ActivityCompat.requestPermissions(
                    (Activity) mContext,
                    PERMISSIONS_STORAGE,
                    REQUEST_EXTERNAL_STORAGE
            );
        } else {

        }
    }

    //
    public void checkFlag(boolean isChecked) {
        Log.e("TradeIn", "checkFlag@66");
        if (isChecked) {
            checkYes();
        } else {
            printDate();
            SimpleDateFormat mDateFormat = new SimpleDateFormat(
                    "dd MMM yyyy HH:mm:ss");
            String enddate = mDateFormat.format(new Date());
            logsSharedPrefsEdit.putString("LogEndDate", enddate);
            logsSharedPrefsEdit.putString("LogContent", getLogs());
            logsSharedPrefsEdit.putString("LogStartStatus", "Completed");
            logsSharedPrefsEdit.commit();
//            shareLogs();
        }
    }

    private void printDate() {
        SimpleDateFormat mDateFormat1 = new SimpleDateFormat(
                "dd MMM yyyy HH:mm:ss");
        String strPrintDate = mDateFormat1.format(new Date());
        Log.e("TradeIn", strPrintDate + "");
    }

    //
    private void checkYes() {
        SimpleDateFormat mDateFormat = new SimpleDateFormat(
                "dd MMM yyyy HH:mm:ss");
        String startDate = mDateFormat
                .format(new Date());
        clearLog();
        saveLogsOnSDCard("");
        logsSharedPrefsEdit.putString("LogStartDate", startDate);
        logsSharedPrefsEdit.putString("LogStartStatus", "Started");
        logsSharedPrefsEdit.putString("LogStartStatus", "Started");
        logsSharedPrefsEdit.commit();
    }

    private void checkNo() {
        logsSharedPrefsEdit.remove("LogEndDate");
        logsSharedPrefsEdit.remove("LogContent");
        logsSharedPrefsEdit.remove("LogStartDate");
        logsSharedPrefsEdit.remove("LogStartStatus");
        logsSharedPrefsEdit.remove("CaptureDone");
        logsSharedPrefsEdit.commit();
        saveLogsOnSDCard("");
    }

    //
    private static final String NEW_LINE = System.getProperty("line.separator");

    private String getLogs() {
        try {
            // "com.example.sample",
            Process process = Runtime.getRuntime().exec(
//                    new String[]{"logcat", "-v", "-d", "-s", "*:i", "*:d", "*:D"});
                    new String[]{"logcat", "-d", "-s", "*:i", "*:d", "*:D"});
//					new String[] { "logcat", "vimm:v" , "-d", "-s", "*:i" });
            BufferedReader bufferedReader = new BufferedReader(
                    new InputStreamReader(process.getInputStream()));

            StringBuilder log = new StringBuilder();
            String line = "";
            Log.i("Start getLogs", "getLogs");
            while ((line = bufferedReader.readLine()) != null) {
                Log.i("Logfile", line);
                log.append(NEW_LINE);
                log.append(line);
            }
            Log.i("End getLogs", "getLogs");
            return log.toString();
        } catch (IOException e) {
            e.printStackTrace();
            LogsCaptureUtils.readLog(e.getMessage());
            return "No Logs::" + e;
        }
    }

    private void clearLog() {
        try {
            Runtime.getRuntime().exec("logcat -c");
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    //
    public void saveLogsOnSDCard(String errorLogString) {
        try {
            File root = LogsCaptureUtils.getLogFileSavedPath(mContext);
            if (!root.exists()) {
                root.mkdirs();
            }
            File gpxfile = new File(root, LogsCaptureUtils.logFileName);
            FileWriter writer = new FileWriter(gpxfile);
            writer.append(errorLogString);
            writer.flush();
            writer.close();
        } catch (IOException e) {
            e.printStackTrace();
            Log.e("IOException", e.getMessage() + "");
            LogsCaptureUtils.readLog(e.getMessage());
        }
    }

    //
    @SuppressLint("StringFormatInvalid")
    public void shareLogs() {
        String content = logsSharedPreferences.getString("LogContent", "");
//        String content = getLogs();
        if (content.length() > 0) {
            String versionName = "";
            try {
                PackageManager manager = mContext.getPackageManager();
                PackageInfo packageInfo = manager.getPackageInfo(mContext.getPackageName(), 0);
                versionName = packageInfo.versionName;
            } catch (PackageManager.NameNotFoundException e) {
                e.printStackTrace();
            }

            String mAdditonalInfo = mContext.getString(R.string.device_info_fmt,
//						getResources().getString(R.string.version_code),
                    versionName,
                    Build.MODEL, Build.VERSION.RELEASE,
                    "", Build.DISPLAY);//getFormattedKernelVersion()
            content = mAdditonalInfo.concat(content);
            saveLogsOnSDCard(content);
            Intent email = new Intent(Intent.ACTION_SEND);
            email.putExtra(Intent.EXTRA_EMAIL, new String[]{});
            email.putExtra(Intent.EXTRA_SUBJECT, mContext.getString(R.string.message_subject));
            email.putExtra(Intent.EXTRA_TEXT, "Please find the TradeIn logs attachment file");
            email.setType("text/plain");
            File root = LogsCaptureUtils.getVideoFilesDirs(mContext, "/TradeIn/");
                /*File myDir1 = new File(Environment.getExternalStorageDirectory().getAbsolutePath(), "/TradeIn/ChatAttachments/");
                if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.R) {
                    myDir1 = new File(getExternalFilesDir(null) + "/TradeIn/ChatAttachments/");
                }*/
            String myAttachedFileName = LogsCaptureUtils.logFileName;
            File file = new File(root, myAttachedFileName);
            if (!file.exists() || !file.canRead()) {
                return;
            }
//                Uri uri = Uri.fromFile(file);
            /*Uri uri = FileProvider.getUriForFile(mContext,
                    "com.andev.logscapture" + ".provider", file);*/
            Uri uri = FileProvider.getUriForFile(mContext,
                    "com.tradeinproject.dev" + ".provider", file);
            Log.e("uri", uri.toString() + "");
            email.putExtra(Intent.EXTRA_STREAM, uri);
            Activity activity = (Activity) mContext;
            activity.startActivity(Intent.createChooser(email, mContext.getString(R.string.chooser_title)));
            activity.overridePendingTransition(R.anim.fedin, R.anim.fedout);
            logsSharedPrefsEdit.remove("LogEndDate");
            logsSharedPrefsEdit.remove("LogContent");
            logsSharedPrefsEdit.remove("LogStartDate");
            logsSharedPrefsEdit.remove("LogStartStatus");
            logsSharedPrefsEdit.commit();
//            findViewById(R.id.logInfoLayout).setVisibility(View.GONE);
//            ((Switch) findViewById(R.id.logging)).setChecked(false);
        } else {
            Toast.makeText(mContext, "No logs to send to server",
                    Toast.LENGTH_SHORT).show();
            logsSharedPrefsEdit.remove("LogEndDate");
            logsSharedPrefsEdit.remove("LogContent");
            logsSharedPrefsEdit.remove("LogStartDate");
            logsSharedPrefsEdit.remove("LogStartStatus");
            logsSharedPrefsEdit.commit();
//            findViewById(R.id.logInfoLayout).setVisibility(View.GONE);
//            ((Switch) findViewById(R.id.logging)).setChecked(false);
        }
    }
}
