package com.concatsys.tradein.tradein_plugin.logscapture;

import android.annotation.SuppressLint;
import android.annotation.TargetApi;
import android.content.Context;
import android.content.SharedPreferences;
import android.os.Build;
import android.os.Environment;
import android.util.Log;

import androidx.core.content.ContextCompat;

import com.faraji.environment3.Device;
import com.faraji.environment3.Environment3;
import com.concatsys.tradein.tradein_plugin.R;

import java.io.File;
import java.util.Map;
import java.util.Set;

public class LogsCaptureUtils {

    public static String preferencesName = "TradeIn";
    public static String logFileName = "TradeInLogs.txt";

    public static File getLogFileSavedPath(Context context) {
        File logFilePath = new File(Environment.getExternalStorageDirectory().getAbsolutePath(), "/TradeIn/");
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.R) {
            logFilePath = new File(context.getExternalFilesDir(null) + "/TradeIn/");
        }
        return logFilePath;

    }

    public static void readLog(String msg) {
        Log.i("TradeIn", " Data : " + msg);
    }

    public static void copySharedPreferences(SharedPreferences fromPreferences, SharedPreferences toPreferences) {
        copySharedPreferences(fromPreferences, toPreferences, true);
    }

    @SuppressLint("ApplySharedPref")
    public static void copySharedPreferences(SharedPreferences fromPreferences, SharedPreferences toPreferences, boolean clear) {
        if (fromPreferences.getAll().entrySet().size() != 0) {
            SharedPreferences.Editor editor = toPreferences.edit();
            if (clear) {
                editor.clear();
            }
            copySharedPreferences(fromPreferences, editor);
            editor.commit();
            SharedPreferences.Editor editor1 = fromPreferences.edit();
            if (clear) {
                editor1.clear();
                editor1.commit();
            }
        }
    }

    @TargetApi(Build.VERSION_CODES.HONEYCOMB)
    @SuppressWarnings({"ConstantConditions"})
    public static void copySharedPreferences(SharedPreferences fromPreferences, SharedPreferences.Editor toEditor) {
        for (Map.Entry<String, ?> entry : fromPreferences.getAll().entrySet()) {
            Object value = entry.getValue();
            String key = entry.getKey();
            if (value instanceof String) {
                toEditor.putString(key, ((String) value));
            } else if (value instanceof Set) {
                toEditor.putStringSet(key, (Set<String>) value); // EditorImpl.putStringSet already creates a copy of the set
            } else if (value instanceof Integer) {
                toEditor.putInt(key, (Integer) value);
            } else if (value instanceof Long) {
                toEditor.putLong(key, (Long) value);
            } else if (value instanceof Float) {
                toEditor.putFloat(key, (Float) value);
            } else if (value instanceof Boolean) {
                toEditor.putBoolean(key, (Boolean) value);
            }
        }
    }

    @SuppressLint("ApplySharedPref")
    public static SharedPreferences loadSharedPreferenceData(Context context) {
        SharedPreferences sharedPreferences = null;
        SharedPreferences oldSharedPreferences = context.getSharedPreferences("PREFS_NAME", 0);
        String userName = oldSharedPreferences.getString("User_Name", "");

        if (userName != null && userName.length() > 0) {
            SharedPreferences preferences = context.getSharedPreferences("APP_USER", 0);
            preferences.edit().putString("App_User", userName).commit();
            LogsCaptureUtils.preferencesName = userName;
            sharedPreferences = context.getSharedPreferences(LogsCaptureUtils.preferencesName, 0);
            LogsCaptureUtils.copySharedPreferences(oldSharedPreferences, sharedPreferences);
            SharedPreferences.Editor editor = sharedPreferences.edit();
            editor.putString("APP_LAUNCH_MODE", context.getResources().getString(R.string.app_server));
            editor.commit();
        } else {
            SharedPreferences preferences = context.getSharedPreferences("APP_USER", 0);
            String AppUser = preferences.getString("App_User", "");
            if (AppUser != null && AppUser.length() > 0) {
                LogsCaptureUtils.preferencesName = AppUser;
            }
            sharedPreferences = context.getSharedPreferences(LogsCaptureUtils.preferencesName, 0);
        }

        return sharedPreferences;
    }


    public static File getVideoFilesDirs(final Context context, final String dirs) {
        File myDir = null;

        String dirPath = "";
        Environment3.rescanDevices();
        Device[] devices = Environment3.getDevices(null, true, true, false);
        boolean isCheckSdCard = hasRealRemovableSdCard(context);
        if (devices.length > 1 && isCheckSdCard) {
            for (int i = 0; i < devices.length; i++) {
                boolean isRemovable = devices[i].isRemovable();
                boolean isWritable = devices[i].isWriteable();
                boolean isAvailable = devices[i].isAvailable();

                SharedPreferences sharedPreferences = loadSharedPreferenceData(context);
                boolean isPhoneMemory = sharedPreferences.getBoolean("MemoryFull", false);
                if (isAvailable && isWritable && isPhoneMemory && isRemovable) {
                    dirPath = devices[i].getMountPoint();
                    SharedPreferences.Editor editor = sharedPreferences.edit();
                    editor.putString("DirPath", dirPath);
                    editor.commit();
                }
            }
        }
        if (dirPath.length() > 0) {
            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.JELLY_BEAN_MR2) {
                File[] files = ContextCompat.getExternalFilesDirs(context, null);
                if (isCheckSdCard) {
                    myDir = new File(files[1], dirs);
                }
            } else {
                myDir = new File(dirPath, dirs);
            }
        } else {
            myDir = new File(Environment.getExternalStorageDirectory().getAbsolutePath(), dirs);
            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.R) {
                myDir = new File(context.getExternalFilesDir(null) + dirs);
            }
        }
        if (!myDir.exists()) {
            myDir.mkdirs();
        }
        return myDir;
    }

    public static boolean hasRealRemovableSdCard(Context context) {

        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.JELLY_BEAN_MR2) {
            return ContextCompat.getExternalFilesDirs(context, null).length >= 2;
        } else {
            return true;
        }
    }

}